@@ -92,29 +92,32 @@ CCDSim::CCDSim()
     //ctor
     testvalue=0;
     AbortGuideFrame=false;
+    AbortPrimaryFrame = false;
     ShowStarField=true;
 
     HasSt4Port=true;
-    HasGuideHead=false;
+    HasGuideHead=true;
 
 
-    RA=9.95;
-    Dec=68.9;
+    raPEC=9.95;
+    decPEC=68.9;
 
     //  sxvh9
     bias=1500;
     maxnoise=20;
     maxval=65000;
+    maxpix=0;
+    minpix =65000;
     limitingmag=11.5;
     saturationmag=2;
     focallength=1280;   //  focal length of the telescope in millimeters
+    guider_focallength=1280;
     OAGoffset=0;    //  An oag is offset this much from center of scope position (arcminutes);
     skyglow=40;
 
     seeing=3.5;         //  fwhm of our stars
     ImageScalex=1.0;    //  preset with a valid non-zero
     ImageScaley=1.0;
-    //focallength=175;   //  focal length of the telescope in millimeters
     time(&RunStart);
 
     //  Our PEPeriod is 8 minutes
@@ -127,27 +130,33 @@ CCDSim::CCDSim()
     SimulatorSettingsNV = new INumberVectorProperty;
     TimeFactorSV = new ISwitchVectorProperty;
 
+    // Filter stuff
+    MinFilter=1;
+    MaxFilter=5;
+    FilterSlotN[0].max = MaxFilter;
+
 }
 
 bool CCDSim::SetupParms()
 {
     int nbuf;
     SetCCDParams(SimulatorSettingsN[0].value,SimulatorSettingsN[1].value,16,SimulatorSettingsN[2].value,SimulatorSettingsN[3].value);
+
     //  Kwiq
-    maxnoise=SimulatorSettingsN[10].value;
-    skyglow=SimulatorSettingsN[11].value;
+    maxnoise=SimulatorSettingsN[8].value;
+    skyglow=SimulatorSettingsN[9].value;
     maxval=SimulatorSettingsN[4].value;
     bias=SimulatorSettingsN[5].value;
     limitingmag=SimulatorSettingsN[7].value;
     saturationmag=SimulatorSettingsN[6].value;
-    focallength=SimulatorSettingsN[8].value;   //  focal length of the telescope in millimeters
-    OAGoffset=SimulatorSettingsN[12].value;    //  An oag is offset this much from center of scope position (arcminutes);
-    seeing=SimulatorSettingsN[9].value;        //  we get real fat stars in this one
+    OAGoffset=SimulatorSettingsN[10].value;    //  An oag is offset this much from center of scope position (arcminutes);
 
-    nbuf = PrimaryCCD.getXRes() * PrimaryCCD.getYRes() * PrimaryCCD.getBPP();
+    nbuf = PrimaryCCD.getXRes() * PrimaryCCD.getYRes() * PrimaryCCD.getBPP()/8;
     nbuf += 512;
     PrimaryCCD.setFrameBufferSize(nbuf);
 
+    GetFilterNames(FILTER_TAB);
+
     return true;
 }
 
@@ -156,13 +165,6 @@ bool CCDSim::Connect()
 
     int nbuf;
 
-    if(HasGuideHead)
-    {
-        SetGuidHeadParams(500,290,8,9.8,12.6);
-        nbuf = GuideCCD.getXRes() * GuideCCD.getYRes();
-        GuideCCD.setFrameBufferSize(nbuf);
-    }
-
     SetTimer(1000);     //  start the timer
     return true;
 }
@@ -183,29 +185,41 @@ bool CCDSim::initProperties()
     //  but the simulators are a special case
     INDI::CCD::initProperties();
 
-    IUFillNumber(&SimulatorSettingsN[0],"SIM_PrimarCCD.getXRes()","CCD X resolution","%4.0f",0,2048,0,1280);
-    IUFillNumber(&SimulatorSettingsN[1],"SIM_PrimarCCD.getYRes()","CCD Y resolution","%4.0f",0,2048,0,1024);
+    IUFillNumber(&SimulatorSettingsN[0],"SIM_XRES","CCD X resolution","%4.0f",0,2048,0,1280);
+    IUFillNumber(&SimulatorSettingsN[1],"SIM_YRES","CCD Y resolution","%4.0f",0,2048,0,1024);
     IUFillNumber(&SimulatorSettingsN[2],"SIM_XSIZE","CCD X Pixel Size","%4.2f",0,60,0,5.2);
     IUFillNumber(&SimulatorSettingsN[3],"SIM_YSIZE","CCD Y Pixel Size","%4.2f",0,60,0,5.2);
     IUFillNumber(&SimulatorSettingsN[4],"SIM_MAXVAL","CCD Maximum ADU","%4.0f",0,65000,0,65000);
     IUFillNumber(&SimulatorSettingsN[5],"SIM_BIAS","CCD Bias","%4.0f",0,6000,0,1500);
     IUFillNumber(&SimulatorSettingsN[6],"SIM_SATURATION","Saturation Mag","%4.1f",0,20,0,1.0);
     IUFillNumber(&SimulatorSettingsN[7],"SIM_LIMITINGMAG","Limiting Mag","%4.1f",0,20,0,20);
-    IUFillNumber(&SimulatorSettingsN[8],"SIM_FOCALLENGTH","Focal Length","%4.0f",0,60000,0,1000);
-    IUFillNumber(&SimulatorSettingsN[9],"SIM_FWHM","FWHM (arcseconds)","%4.2f",0,60,0,3.5);
-    IUFillNumber(&SimulatorSettingsN[10],"SIM_NOISE","CCD Noise","%4.0f",0,6000,0,50);
-    IUFillNumber(&SimulatorSettingsN[11],"SIM_SKYGLOW","Sky Glow (magnitudes)","%4.1f",0,6000,0,19.5);
-    IUFillNumber(&SimulatorSettingsN[12],"SIM_OAGOFFSET","Oag Offset (arminutes)","%4.1f",0,6000,0,0);
-    IUFillNumberVector(SimulatorSettingsNV,SimulatorSettingsN,13,deviceName(),"SIMULATOR_SETTINGS","Simulator Settings","Simulator Config",IP_RW,60,IPS_IDLE);
+    IUFillNumber(&SimulatorSettingsN[8],"SIM_NOISE","CCD Noise","%4.0f",0,6000,0,50);
+    IUFillNumber(&SimulatorSettingsN[9],"SIM_SKYGLOW","Sky Glow (magnitudes)","%4.1f",0,6000,0,19.5);
+    IUFillNumber(&SimulatorSettingsN[10],"SIM_OAGOFFSET","Oag Offset (arcminutes)","%4.1f",0,6000,0,0);
+    IUFillNumberVector(SimulatorSettingsNV,SimulatorSettingsN,11,getDeviceName(),"SIMULATOR_SETTINGS","Simulator Settings","Simulator Config",IP_RW,60,IPS_IDLE);
 
 
     IUFillSwitch(&TimeFactorS[0],"1X","Actual Time",ISS_ON);
     IUFillSwitch(&TimeFactorS[1],"10X","10x",ISS_OFF);
     IUFillSwitch(&TimeFactorS[2],"100X","100x",ISS_OFF);
-    IUFillSwitchVector(TimeFactorSV,TimeFactorS,3,deviceName(),"ON_TIME_FACTOR","Time Factor","Simulator Config",IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitchVector(TimeFactorSV,TimeFactorS,3,getDeviceName(),"ON_TIME_FACTOR","Time Factor","Simulator Config",IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
+    IUFillNumber(&FWHMN[0],"SIM_FWHM","FWHM (arcseconds)","%4.2f",0,60,0,7.5);
+    IUFillNumberVector(&FWHMNP,FWHMN,1,"Focuser Simulator", "FWHM","FWHM",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
 
-    //loadConfig();
+    IUFillNumber(&ScopeParametersN[0],"TELESCOPE_APERTURE","Aperture (mm)","%g",50,4000,0,0.0);
+    IUFillNumber(&ScopeParametersN[1],"TELESCOPE_FOCAL_LENGTH","Focal Length (mm)","%g",100,10000,0,0.0 );
+    IUFillNumber(&ScopeParametersN[2],"GUIDER_APERTURE","Guider Aperture (mm)","%g",50,4000,0,0.0);
+    IUFillNumber(&ScopeParametersN[3],"GUIDER_FOCAL_LENGTH","Guider Focal Length (mm)","%g",100,10000,0,0.0 );
+    IUFillNumberVector(&ScopeParametersNP,ScopeParametersN,4,"Telescope Simulator","TELESCOPE_INFO","Scope Properties",OPTIONS_TAB,IP_RW,60,IPS_OK);
+
+    IUFillNumber(&EqPECN[0],"RA_PEC","Ra (hh:mm:ss)","%010.6m",0,24,0,0);
+    IUFillNumber(&EqPECN[1],"DEC_PEC","decPEC (dd:mm:ss)","%010.6m",-90,90,0,0);
+    IUFillNumberVector(&EqPECNP,EqPECN,2,ActiveDeviceT[0].text,"EQUATORIAL_PEC","EQ PEC","Main Control",IP_RW,60,IPS_IDLE);
+
+    IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PEC");
+
+    initFilterProperties(getDeviceName(), FILTER_TAB);
 
     return true;
 }
@@ -219,22 +233,29 @@ void CCDSim::ISGetProperties (const char *dev)
 
     defineNumber(SimulatorSettingsNV);
     defineSwitch(TimeFactorSV);
-    //IDDefText(&ConfigFileTV, NULL);
-    //IDDefSwitch(&ConfigSaveRestoreSV, NULL);
-
 
     return;
 }
 
 bool CCDSim::updateProperties()
 {
-    IDDefNumber(SimulatorSettingsNV, NULL);
-
     INDI::CCD::updateProperties();
 
     if (isConnected())
+    {
         SetupParms();
 
+        if(HasGuideHead)
+        {
+            SetGuidHeadParams(500,290,16,9.8,12.6);
+            GuideCCD.setFrameBufferSize(GuideCCD.getXRes() * GuideCCD.getYRes() * 2);
+        }
+
+        defineNumber(&FilterSlotNP);
+        if (FilterNameT != NULL)
+            defineText(FilterNameTP);
+    }
+
     return true;
 }
 
@@ -249,21 +270,15 @@ int CCDSim::StartExposure(float duration)
     //  for the simulator, we can just draw the frame now
     //  and it will get returned at the right time
     //  by the timer routines
+    AbortPrimaryFrame=false;
     ExposureRequest=duration;
 
-    if(InExposure)
-    {
-        //  We are already in an exposure, just change the time
-        //  and be done with it.
-        return 0;
-    }
-
+    PrimaryCCD.setExposureDuration(duration);
     gettimeofday(&ExpStart,NULL);
     //  Leave the proper time showing for the draw routines
-    DrawCcdFrame();
+    DrawCcdFrame(&PrimaryCCD);
     //  Now compress the actual wait time
     ExposureRequest=duration*TimeFactor;
-
     InExposure=true;
     return 0;
 }
@@ -271,13 +286,24 @@ int CCDSim::StartExposure(float duration)
 int CCDSim::StartGuideExposure(float n)
 {
     GuideExposureRequest=n;
-    if(InGuideExposure) return 0;
-    DrawGuiderFrame();
+    AbortGuideFrame = false;
+    GuideCCD.setExposureDuration(n);
+    DrawCcdFrame(&GuideCCD);
     gettimeofday(&GuideExpStart,NULL);
     InGuideExposure=true;
     return 0;
 }
 
+bool CCDSim::AbortExposure()
+{
+    if (!InExposure)
+        return true;
+
+    AbortPrimaryFrame = true;
+
+    return true;
+}
+
 bool CCDSim::AbortGuideExposure()
 {
     //IDLog("Enter AbortGuideExposure\n");
@@ -307,25 +333,32 @@ void CCDSim::TimerHit()
 
     if(InExposure)
     {
-        float timeleft;
-        timeleft=CalcTimeLeft(ExpStart,ExposureRequest);
-
-        if (timeleft < 0)
-             timeleft = 0;
-
-        PrimaryCCD.setExposure(timeleft);
-        //ImageExposureN[0].value = timeleft;
-        //IDSetNumber(ImageExposureNP, NULL);
-
-        if(timeleft < 1.0)
+        if (AbortPrimaryFrame)
         {
-            if(timeleft <= 0.001)
+            InExposure = false;
+            AbortPrimaryFrame = false;
+        }
+        else
+        {
+            float timeleft;
+            timeleft=CalcTimeLeft(ExpStart,ExposureRequest);
+
+            //IDLog("CCD Exposure left: %g - Requset: %g\n", timeleft, ExposureRequest);
+            if (timeleft < 0)
+                 timeleft = 0;
+
+            PrimaryCCD.setExposureLeft(timeleft);
+
+            if(timeleft < 1.0)
             {
-                InExposure=false;
-                ExposureComplete();
-            } else
-            {
-                nexttimer=timeleft*1000;    //  set a shorter timer
+                if(timeleft <= 0.001)
+                {
+                    InExposure=false;
+                    ExposureComplete(&PrimaryCCD);
+                } else
+                {
+                    nexttimer=timeleft*1000;    //  set a shorter timer
+                }
             }
         }
     }
@@ -336,12 +369,14 @@ void CCDSim::TimerHit()
         timeleft=CalcTimeLeft(GuideExpStart,GuideExposureRequest);
 
 
+        //IDLog("GUIDE Exposure left: %g - Requset: %g\n", timeleft, GuideExposureRequest);
+
         if (timeleft < 0)
              timeleft = 0;
 
         //ImageExposureN[0].value = timeleft;
         //IDSetNumber(ImageExposureNP, NULL);
-        GuideCCD.setExposure(timeleft);
+        GuideCCD.setExposureLeft(timeleft);
 
         if(timeleft < 1.0)
         {
@@ -351,7 +386,7 @@ void CCDSim::TimerHit()
                 if(!AbortGuideFrame)
                 {
                     //IDLog("Sending guider frame\n");
-                    GuideExposureComplete();
+                    ExposureComplete(&GuideCCD);
                     if(InGuideExposure)
                     {    //  the call to complete triggered another exposure
                         timeleft=CalcTimeLeft(GuideExpStart,GuideExposureRequest);
@@ -375,14 +410,28 @@ void CCDSim::TimerHit()
     return;
 }
 
-int CCDSim::DrawCcdFrame()
+int CCDSim::DrawCcdFrame(CCDChip *targetChip)
 {
     //  Ok, lets just put a silly pattern into this
     //  CCd frame is 16 bit data
     unsigned short int *ptr;
     unsigned short int val;
+    float ExposureTime;
+    float targetFocalLength;
+
+    ptr=(unsigned short int *) targetChip->getFrameBuffer();
+
+    if (targetChip->getXRes() == 500)
+    {
+        targetFocalLength = guider_focallength;
+        ExposureTime = GuideExposureRequest*4;
+    }
+    else
+    {
+        targetFocalLength = focallength;
+        ExposureTime = ExposureRequest;
+    }
 
-    ptr=(unsigned short int *) PrimaryCCD.getFrameBuffer();
 
     if(ShowStarField)
     {
@@ -416,7 +465,7 @@ int CCDSim::DrawCcdFrame()
         //PeOffset=PeOffset/15;       //  ra is in h:mm
 
         //  Start by clearing the frame buffer
-        memset(PrimaryCCD.getFrameBuffer(),0,PrimaryCCD.getFrameBufferSize());
+        memset(targetChip->getFrameBuffer(),0,targetChip->getFrameBufferSize());
 
 
         //  Spin up a set of plate constants that will relate
@@ -432,14 +481,14 @@ int CCDSim::DrawCcdFrame()
         //  for now we cheat
         //  no offset or rotation for and y axis means
         pb=0.0;
-        pc=PrimaryCCD.getXRes()/2/PrimaryCCD.getBinX();
+        pc=targetChip->getXRes()/2/targetChip->getBinX();
         pd=0.0;
-        pf=PrimaryCCD.getYRes()/2/PrimaryCCD.getBinY();
+        pf=targetChip->getYRes()/2/targetChip->getBinY();
         //  and we do a simple scale for x and y locations
         //  based on the focal length and pixel size
         //  focal length in mm, pixels in microns
-        pa=focallength/PrimaryCCD.getPixelSizeX()*1000/PrimaryCCD.getBinX();
-        pe=focallength/PrimaryCCD.getPixelSizeY()*1000/PrimaryCCD.getBinY();
+        pa=targetFocalLength/targetChip->getPixelSizeX()*1000/targetChip->getBinX();
+        pe=targetFocalLength/targetChip->getPixelSizeY()*1000/targetChip->getBinY();
 
         //IDLog("Pixels are %4.2f %4.2f  pa %6.4f  pe %6.4f\n",PixelSizex,PixelSizey,pa,pe);
 
@@ -460,18 +509,18 @@ int CCDSim::DrawCcdFrame()
         ImageScaley=Scaley;
 
         //  calc this now, we will use it a lot later
-        rad=RA*15.0;
+        rad=raPEC*15.0;
         rar=rad*0.0174532925;
         //  offsetting the dec by the guide head offset
         float cameradec;
-        cameradec=Dec+OAGoffset/60;
+        cameradec=decPEC+OAGoffset/60;
         decr=cameradec*0.0174532925;
 
-        //fprintf(stderr,"Dec %7.5f  cameradec %7.5f  CenterOffsetDec %4.4f\n",Dec,cameradec,CenterOffsetDec);
+        //fprintf(stderr,"decPEC %7.5f  cameradec %7.5f  CenterOffsetDec %4.4f\n",decPEC,cameradec,CenterOffsetDec);
         //  now lets calculate the radius we need to fetch
         float radius;
 
-        radius=sqrt((Scalex*Scalex*PrimaryCCD.getXRes()/2.0*PrimaryCCD.getXRes()/2.0)+(Scaley*Scaley*PrimaryCCD.getYRes()/2.0*PrimaryCCD.getYRes()/2.0));
+        radius=sqrt((Scalex*Scalex*targetChip->getXRes()/2.0*targetChip->getXRes()/2.0)+(Scaley*Scaley*targetChip->getYRes()/2.0*targetChip->getYRes()/2.0));
         //  we have radius in arcseconds now
         radius=radius/60;   //  convert to arcminutes
         //fprintf(stderr,"Lookup radius %4.2f\n",radius);
@@ -498,9 +547,9 @@ int CCDSim::DrawCcdFrame()
         if(radius > 60) lookuplimit=11;
 
         //  if this is a light frame, we need a star field drawn
-        if(PrimaryCCD.getFrameType()==CCDChip::LIGHT_FRAME)
+        if(targetChip->getFrameType()==CCDChip::LIGHT_FRAME)
         {
-            //sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r 120 -m 0 9.1",rad+PEOffset,Dec);
+            //sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r 120 -m 0 9.1",rad+PEOffset,decPEC);
             sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r %4.1f -m 0 %4.2f -n 3000",rad+PEOffset,cameradec,radius,lookuplimit);
             //fprintf(stderr,"gsccmd %s\n",gsccmd);
             pp=popen(gsccmd,"r");
@@ -560,10 +609,11 @@ int CCDSim::DrawCcdFrame()
                         ccdy=pd*sx+pe*sy+pf;
 
 
-                        rc=DrawImageStar(mag,ccdx,ccdy);
+                        rc=DrawImageStar(targetChip, mag,ccdx,ccdy);
                         drawn+=rc;
-                        if(rc==1) {
-                            //fprintf(stderr,"star %s scope %6.4f %6.4f star %6.4f %6.4f  ccd %6.2f %6.2f\n",id,rad,Dec,ra,dec,ccdx,ccdy);
+                        if(rc==1)
+                        {
+                            //fprintf(stderr,"star %s scope %6.4f %6.4f star %6.4f %6.4f  ccd %6.2f %6.2f\n",id,rad,decPEC,ra,dec,ccdx,ccdy);
                             //fprintf(stderr,"star %s ccd %6.2f %6.2f\n",id,ccdx,ccdy);
                         }
                     }
@@ -571,12 +621,12 @@ int CCDSim::DrawCcdFrame()
                 pclose(pp);
             } else
             {
-                IDMessage(deviceName(),"Error looking up stars, is gsc installed with appropriate environment variables set ??");
+                IDMessage(getDeviceName(),"Error looking up stars, is gsc installed with appropriate environment variables set ??");
                 //fprintf(stderr,"Error doing gsc lookup\n");
             }
             if(drawn==0)
             {
-                IDMessage(deviceName(),"Got no stars, is gsc installed with appropriate environment variables set ??");
+                IDMessage(getDeviceName(),"Got no stars, is gsc installed with appropriate environment variables set ??");
 
             }
         }
@@ -586,7 +636,7 @@ int CCDSim::DrawCcdFrame()
         //  this is essentially the same math as drawing a dim star with
         //  fwhm equivalent to the full field of view
 
-        CCDChip::CCD_FRAME ftype = PrimaryCCD.getFrameType();
+        CCDChip::CCD_FRAME ftype = targetChip->getFrameType();
 
         if((ftype==CCDChip::LIGHT_FRAME)||(ftype==CCDChip::FLAT_FRAME))
         {
@@ -601,31 +651,36 @@ int CCDSim::DrawCcdFrame()
                 //  is much brighter than at night
                 glow=skyglow/10;
             }
+
             //fprintf(stderr,"Using glow %4.2f\n",glow);
+
             skyflux=pow(10,((glow-z)*k/-2.5));
             //  ok, flux represents one second now
             //  scale up linearly for exposure time
-            skyflux=skyflux*ExposureRequest*PrimaryCCD.getBinX()*PrimaryCCD.getBinY();
-            //IDLog("SkyFlux = %4.2f ExposureRequest %4.2f\n",skyflux,ExposureRequest);
+            skyflux=skyflux*ExposureTime*targetChip->getBinX()*targetChip->getBinY();
+           //IDLog("SkyFlux = %g ExposureRequest %g\n",skyflux,ExposureTime);
 
             unsigned short *pt;
 
-            int nwidth  = PrimaryCCD.getXRes()/PrimaryCCD.getBinX();
-            int nheight = PrimaryCCD.getYRes()/PrimaryCCD.getBinY();
-            pt=(unsigned short int *)PrimaryCCD.getFrameBuffer();
-            for(int y=0; y< nheight; y++) {
-                for(int x=0; x< nwidth; x++) {
+            int nwidth  = targetChip->getXRes()/targetChip->getBinX();
+            int nheight = targetChip->getYRes()/targetChip->getBinY();
+            pt=(unsigned short int *)targetChip->getFrameBuffer();
+
+            for(int y=0; y< nheight; y++)
+            {
+                for(int x=0; x< nwidth; x++)
+                {
                     float dc;   //  distance from center
                     float fp;   //  flux this pixel;
                     float sx,sy;
                     float vig;
 
-                    sx=PrimaryCCD.getXRes()/2/PrimaryCCD.getBinX();
+                    sx=targetChip->getXRes()/2/targetChip->getBinX();
                     sx=sx-x;
-                    sy=PrimaryCCD.getYRes()/2/PrimaryCCD.getBinY();
+                    sy=targetChip->getYRes()/2/targetChip->getBinY();
                     sy=sy-y;
 
-                    vig=PrimaryCCD.getXRes()/PrimaryCCD.getBinX();
+                    vig=targetChip->getXRes()/targetChip->getBinX();
                     vig=vig*ImageScalex;
                     //  need to make this account for actual pixel size
                     dc=sqrt(sx*sx*ImageScalex*ImageScalex+sy*sy*ImageScaley*ImageScaley);
@@ -634,14 +689,20 @@ int CCDSim::DrawCcdFrame()
                     //
                     float fa;
                     fa=exp(-2.0*0.7*(dc*dc)/vig/vig);
+
                     //  get the current value
                     fp=pt[0];
+
                     //  Add the sky glow
                     fp+=skyflux;
+
                     //  now scale it for the vignetting
                     fp=fa*fp;
+
                     //  clamp to limits
                     if(fp > maxval) fp=maxval;
+                    if (fp > maxpix) maxpix = fp;
+                    if (fp < minpix) minpix = fp;
                     //  and put it back
                     pt[0]=fp;
                     pt++;
@@ -652,14 +713,15 @@ int CCDSim::DrawCcdFrame()
 
 
         //  Now we add some bias and read noise
-        for(x=0; x<PrimaryCCD.getXRes(); x++) {
-            for(y=0; y<PrimaryCCD.getYRes(); y++) {
+        for(x=0; x<targetChip->getXRes(); x++) {
+            for(y=0; y<targetChip->getYRes(); y++) {
                 int noise;
 
                 noise=random();
                 noise=noise%maxnoise; //
 
-                AddToPixel(x,y,bias+noise);
+                //IDLog("noise is %d\n", noise);
+                AddToPixel(targetChip, x,y,bias+noise);
             }
         }
 
@@ -669,7 +731,7 @@ int CCDSim::DrawCcdFrame()
         if(testvalue > 255) testvalue=0;
         val=testvalue;
 
-        int nbuf    = PrimaryCCD.getXRes()*PrimaryCCD.getYRes();
+        int nbuf    = targetChip->getXRes()*targetChip->getYRes();
 
         for(int x=0; x<nbuf; x++)
         {
@@ -681,26 +743,7 @@ int CCDSim::DrawCcdFrame()
     return 0;
 }
 
-int CCDSim::DrawGuiderFrame()
-{
-    unsigned char *ptr;
-    unsigned char val;
-
-    ptr=(unsigned char *) GuideCCD.getFrameBuffer();
-    testvalue++;
-    if(testvalue > 255) testvalue=0;
-    val=testvalue;
-
-    int nbuf = GuideCCD.getXRes()*GuideCCD.getYRes();
-    for(int x=0; x< nbuf; x++)
-    {
-        *ptr=val++;
-        ptr++;
-    }
-    return 0;
-}
-
-int CCDSim::DrawImageStar(float mag,float x,float y)
+int CCDSim::DrawImageStar(CCDChip *targetChip, float mag,float x,float y)
 {
     //float d;
     //float r;
@@ -709,8 +752,15 @@ int CCDSim::DrawImageStar(float mag,float x,float y)
     int boxsizex=5;
     int boxsizey=5;
     float flux;
+    float ExposureTime;
 
-    if((x<0)||(x>PrimaryCCD.getXRes()/PrimaryCCD.getBinX())||(y<0)||(y>PrimaryCCD.getYRes()/PrimaryCCD.getBinY()))
+    if (targetChip->getXRes() == 500)
+        ExposureTime = GuideExposureRequest*4;
+    else
+        ExposureTime = ExposureRequest;
+
+
+    if((x<0)||(x>targetChip->getXRes()/targetChip->getBinX())||(y<0)||(y>targetChip->getYRes()/targetChip->getBinY()))
     {
         //  this star is not on the ccd frame anyways
         return 0;
@@ -720,10 +770,10 @@ int CCDSim::DrawImageStar(float mag,float x,float y)
 
     //  calculate flux from our zero point and gain values
     flux=pow(10,((mag-z)*k/-2.5));
+
     //  ok, flux represents one second now
     //  scale up linearly for exposure time
-    flux=flux*ExposureRequest;
-
+    flux=flux*ExposureTime;
 
     float qx;
     //  we need a box size that gives a radius at least 3 times fwhm
@@ -752,7 +802,9 @@ int CCDSim::DrawImageStar(float mag,float x,float y)
             //  a simple linear function
             float fa;
             fa=exp(-2.0*0.7*(dc*dc)/seeing/seeing);
-            fp=fa*flux*PrimaryCCD.getBinX()*PrimaryCCD.getBinY();
+            fp=fa*flux*targetChip->getBinX()*targetChip->getBinY();
+
+
             if(fp < 0) fp=0;
 
             /*
@@ -764,29 +816,33 @@ int CCDSim::DrawImageStar(float mag,float x,float y)
                 fp=0;
             }
             */
-            rc=AddToPixel(x+sx,y+sy,fp);
+            rc=AddToPixel(targetChip, x+sx,y+sy,fp);
             if(rc != 0) drew=1;
         }
     }
     return drew;
 }
 
-int CCDSim::AddToPixel(int x,int y,int val)
+int CCDSim::AddToPixel(CCDChip *targetChip, int x,int y,int val)
 {
     int drew=0;
     if(x >= 0) {
-        if(x < PrimaryCCD.getXRes()/PrimaryCCD.getBinX()) {
+        if(x < targetChip->getXRes()/targetChip->getBinX()) {
             if(y >= 0) {
-                if(y < PrimaryCCD.getYRes()/PrimaryCCD.getBinY()) {
+                if(y < targetChip->getYRes()/targetChip->getBinY()) {
                     unsigned short *pt;
                     int newval;
                     drew++;
-                    pt=(unsigned short int *)PrimaryCCD.getFrameBuffer();
-                    pt+=(y*PrimaryCCD.getXRes()/PrimaryCCD.getBinX());
+
+                    pt=(unsigned short int *)targetChip->getFrameBuffer();
+
+                    pt+=(y*targetChip->getXRes()/targetChip->getBinX());
                     pt+=x;
                     newval=pt[0];
                     newval+=val;
                     if(newval > maxval) newval=maxval;
+                    if (newval > maxpix) maxpix = newval;
+                    if (newval < minpix) minpix = newval;
                     pt[0]=newval;
                 }
             }
@@ -799,9 +855,9 @@ bool CCDSim::GuideNorth(float v)
 {
     float c;
 
-    c=v*GuideRate;  //
+    c=v/1000*GuideRate;  //
     c=c/3600;
-    Dec=Dec+c;
+    decPEC=decPEC+c;
 
     return true;
 }
@@ -809,9 +865,9 @@ bool CCDSim::GuideSouth(float v)
 {
     float c;
 
-    c=v*GuideRate;  //
+    c=v/1000*GuideRate;  //
     c=c/3600;
-    Dec=Dec-c;
+    decPEC=decPEC-c;
 
     return true;
 }
@@ -820,10 +876,10 @@ bool CCDSim::GuideEast(float v)
 {
     float c;
 
-    c=v*GuideRate;
+    c=v/1000*GuideRate;
     c=c/3600.0/15.0;
-    c=c/(cos(Dec*0.0174532925));
-    RA=RA-c;
+    c=c/(cos(decPEC*0.0174532925));
+    raPEC=raPEC+c;
 
     return true;
 }
@@ -831,10 +887,10 @@ bool CCDSim::GuideWest(float v)
 {
     float c;
 
-    c=v*GuideRate;  //
+    c=v/1000*GuideRate;  //
     c=c/3600.0/15.0;
-    c=c/(cos(Dec*0.0174532925));
-    RA=RA+c;
+    c=c/(cos(decPEC*0.0174532925));
+    raPEC=raPEC-c;
 
     return true;
 }
@@ -843,31 +899,17 @@ bool CCDSim::ISNewNumber (const char *dev, const char *name, double values[], ch
 {
     //  first check if it's for our device
     //IDLog("INDI::CCD::ISNewNumber %s\n",name);
-    if(strcmp(dev,deviceName())==0)
+    if(strcmp(dev,getDeviceName())==0)
     {
         //  This is for our device
         //  Now lets see if it's something we process here
 
         //IDLog("CCDSim::ISNewNumber %s\n",name);
-        if(strcmp(name,"SIMULATOR_SETTINGS")==0) {
-            //  We are being asked to set camera binning
+        if(strcmp(name,"SIMULATOR_SETTINGS")==0)
+        {
+            IUUpdateNumber(SimulatorSettingsNV, values, names, n);
             SimulatorSettingsNV->s=IPS_OK;
 
-            for(int x=0; x<n; x++) {
-                //fprintf(stderr,"name %s value %4.2f\n",names[x],values[x]);
-                if(values[x] != 0) {
-                    SimulatorSettingsN[x].value=values[x];
-                } else {
-                    //  We ignore zeros on most of our items
-                    //  because they likely mean it was just a field not
-                    //  actually filled in, but, for the dec offset it is
-                    //  important to keep a zero value
-                    if(strcmp(names[x],"SIM_OAGOFFSET")==0) {
-                        SimulatorSettingsN[x].value=values[x];
-                    }
-                }
-            }
-
             //  Reset our parameters now
             SetupParms();
             IDSetNumber(SimulatorSettingsNV,NULL);
@@ -878,6 +920,12 @@ bool CCDSim::ISNewNumber (const char *dev, const char *name, double values[], ch
             return true;
         }
 
+        if (strcmp(name, FilterSlotNP.name)==0)
+        {
+            processFilterProperties(name, values, names, n);
+            return true;
+        }
+
 
     }
     //  if we didn't process it, continue up the chain, let somebody else
@@ -893,7 +941,7 @@ bool CCDSim::ISNewSwitch (const char *dev, const char *name, ISState *states, ch
     //    IDLog("Switch %s %d\n",names[x],states[x]);
     //}
 
-    if(strcmp(dev,deviceName())==0) {
+    if(strcmp(dev,getDeviceName())==0) {
         //  This one is for us
 
 
@@ -928,3 +976,91 @@ bool CCDSim::ISNewSwitch (const char *dev, const char *name, ISState *states, ch
     return INDI::CCD::ISNewSwitch(dev,name,states,names,n);
 }
 
+bool CCDSim::ISSnoopDevice (XMLEle *root)
+{
+     if (IUSnoopNumber(root,&FWHMNP)==0)
+     {
+           seeing = FWHMNP.np[0].value;
+
+           if (isDebug())
+                IDLog("CCD Simulator: New FWHM value of %g\n", seeing);
+           return true;
+     }
+
+     if (IUSnoopNumber(root,&ScopeParametersNP)==0)
+     {
+           focallength = ScopeParametersNP.np[1].value;
+           guider_focallength = ScopeParametersNP.np[3].value;
+           if (isDebug())
+           {
+                IDLog("CCD Simulator: New focalLength value of %g\n", focallength);
+                IDLog("CCD Simulator: New guider_focalLength value of %g\n", guider_focallength);
+           }
+           return true;
+     }
+
+     if(IUSnoopNumber(root,&EqPECNP)==0)
+     {
+        float newra,newdec;
+        newra=EqPECN[0].value;
+        newdec=EqPECN[1].value;
+        if((newra != raPEC)||(newdec != decPEC))
+        {
+            if (isDebug())
+                IDLog("raPEC %4.2f  decPEC %4.2f Snooped raPEC %4.2f  decPEC %4.2f\n",raPEC,decPEC,newra,newdec);
+            raPEC=newra;
+            decPEC=newdec;
+
+            return true;
+
+        }
+     }
+
+     return INDI::CCD::ISSnoopDevice(root);
+}
+
+bool CCDSim::saveConfigItems(FILE *fp)
+{
+    INDI::CCD::saveConfigItems(fp);
+
+    IUSaveConfigNumber(fp,SimulatorSettingsNV);
+    IUSaveConfigSwitch(fp, TimeFactorSV);
+
+    return true;
+}
+
+bool CCDSim::SelectFilter(int f)
+{
+    CurrentFilter = f;
+    SelectFilterDone(f);
+}
+
+bool CCDSim::GetFilterNames(const char* groupName)
+{
+    char filterName[MAXINDINAME];
+    char filterLabel[MAXINDILABEL];
+
+    const char *filterDesignation[5] = { "Red", "Green", "Blue", "H_Alpha", "Luminosity" };
+
+    if (FilterNameT != NULL)
+        delete FilterNameT;
+
+    FilterNameT = new IText[MaxFilter];
+
+    for (int i=0; i < MaxFilter; i++)
+    {
+        snprintf(filterName, MAXINDINAME, "FILTER_SLOT_NAME_%d", i+1);
+        snprintf(filterLabel, MAXINDILABEL, "Filter #%d", i+1);
+        IUFillText(&FilterNameT[i], filterName, filterLabel, filterDesignation[i]);
+    }
+
+    IUFillTextVector(FilterNameTP, FilterNameT, MaxFilter, getDeviceName(), "FILTER_NAME", "Filter", groupName, IP_RW, 0, IPS_IDLE);
+
+    return true;
+}
+
+int CCDSim::QueryFilter()
+{
+    return CurrentFilter;
+}
+
