@@ -20,15 +20,19 @@
 #define CCDSIM_H
 
 #include "indibase/indiccd.h"
+#include "indibase/indifilterinterface.h"
 
 /*  Some headers we need */
 #include <math.h>
 #include <sys/time.h>
 
 
-class CCDSim : public INDI::CCD
+class CCDSim : public INDI::CCD, public INDI::FilterInterface
 {
     protected:
+
+    virtual bool saveConfigItems(FILE *fp);
+
     private:
 
         bool InExposure;
@@ -46,6 +50,8 @@ class CCDSim : public INDI::CCD
         int bias;
         int maxnoise;
         int maxval;
+        int maxpix;
+        int minpix;
         float skyglow;
         float limitingmag;
         float saturationmag;
@@ -53,6 +59,7 @@ class CCDSim : public INDI::CCD
         float ImageScalex;
         float ImageScaley;
         float focallength;
+        float guider_focallength;
         float OAGoffset;
         float TimeFactor;
         //  our zero point calcs used for drawing stars
@@ -60,24 +67,44 @@ class CCDSim : public INDI::CCD
         float z;
 
         bool AbortGuideFrame;
+        bool AbortPrimaryFrame;
 
 
         float GuideRate;
 
         float PEPeriod;
         float PEMax;
+
+        double raPEC,decPEC;
         time_t RunStart;
 
         //  And this lives in our simulator settings page
 
         INumberVectorProperty *SimulatorSettingsNV;
-        INumber SimulatorSettingsN[13];
+        INumber SimulatorSettingsN[11];
 
         ISwitch TimeFactorS[3];
         ISwitchVectorProperty *TimeFactorSV;
 
         bool SetupParms();
 
+        //  We are going to snoop these from focuser
+        INumberVectorProperty FWHMNP;
+        INumber FWHMN[1];
+
+        // We are going to snoop these from telescope
+        INumber ScopeParametersN[4];
+        INumberVectorProperty ScopeParametersNP;
+
+        INumberVectorProperty EqPECNP;
+        INumber EqPECN[2];
+
+        // Filter
+        bool SelectFilter(int);
+        bool SetFilterNames() { return false; }
+        bool GetFilterNames(const char* groupName);
+        int QueryFilter();
+
     public:
         CCDSim();
         virtual ~CCDSim();
@@ -95,16 +122,17 @@ class CCDSim : public INDI::CCD
 
         int StartExposure(float duration);
         int StartGuideExposure(float);
+
+        bool AbortExposure();
         bool AbortGuideExposure();
 
 
         void TimerHit();
 
-        int DrawCcdFrame();
-        int DrawGuiderFrame();
+        int DrawCcdFrame(CCDChip *targetChip);
 
-        int DrawImageStar(float,float,float);
-        int AddToPixel(int,int,int);
+        int DrawImageStar(CCDChip *targetChip, float,float,float);
+        int AddToPixel(CCDChip *targetChip, int,int,int);
 
         bool GuideNorth(float);
         bool GuideSouth(float);
@@ -113,6 +141,7 @@ class CCDSim : public INDI::CCD
 
         virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
         virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
+        virtual bool ISSnoopDevice (XMLEle *root);
 
 };
 
