@@ -41,6 +41,8 @@ public:
     virtual bool ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n);
     virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
     virtual bool Move(FocusDirection dir, int speed, int duration);
+    virtual int MoveAbs(int ticks);
+    virtual int MoveRel(FocusDirection dir, unsigned int ticks);
 
 private:
 
@@ -85,9 +87,6 @@ private:
     INumber SetRegisterPositionN[1];
     INumberVectorProperty SetRegisterPositionNP;
 
-    INumber PositionN[1];
-    INumberVectorProperty PositionNP;
-
     INumber RelMovementN[1];
     INumberVectorProperty RelMovementNP;
 
