@@ -87,7 +87,7 @@ int setCommandInt(int fd, int data, const char *cmd);
 /* Set Sexigesimal */
 int setCommandXYZ(int fd, int x, int y, int z, const char *cmd);
 /* Common routine for Set commands */
-int setStandardProcedure(int fd, char * writeData);
+int setStandardProcedure(int fd, const char * writeData);
 /* Set Slew Mode */
 int setSlewMode(int fd, int slewMode);
 /* Set Alignment mode */
@@ -219,8 +219,12 @@ int getCommandSexa(int fd, double *value, const char * cmd)
   
   /*if ( (read_ret = portRead(temp_string, -1, LX200_TIMEOUT)) < 1)
      return read_ret;*/
-  tty_read_section(fd, temp_string, '#', LX200_TIMEOUT, &nbytes_read);
- 
+
+  error_type = tty_read_section(fd, temp_string, '#', LX200_TIMEOUT, &nbytes_read);
+  tcflush(fd, TCIFLUSH);
+  if (error_type != TTY_OK)
+    return error_type;
+
   temp_string[nbytes_read - 1] = '\0';
   
   /*IDLog("getComandSexa: %s\n", temp_string);*/
@@ -250,7 +254,10 @@ int getCommandInt(int fd, int *value, const char* cmd)
   if ( (error_type = tty_write_string(fd, cmd, &nbytes_write)) != TTY_OK)
    return error_type;
   
-  tty_read_section(fd, temp_string, '#', LX200_TIMEOUT, &nbytes_read);
+  error_type = tty_read_section(fd, temp_string, '#', LX200_TIMEOUT, &nbytes_read);
+  tcflush(fd, TCIFLUSH);
+  if (error_type != TTY_OK)
+    return error_type;
  
   temp_string[nbytes_read - 1] = '\0';
 
@@ -684,7 +691,7 @@ int updateIntelliscopeCoord (int fd, double *ra, double *dec)
 * SET
 **********************************************************************/
 
-int setStandardProcedure(int fd, char * data)
+int setStandardProcedure(int fd, const char * data)
 {
  char bool_return[2];
  int error_type;
