@@ -68,8 +68,6 @@ extern char* me;
 /* Handy Macros */
 #define currentRA	EquatorialCoordsRN[0].value
 #define currentDEC	EquatorialCoordsRN[1].value
-#define targetRA	EquatorialCoordsWN[0].value
-#define targetDEC	EquatorialCoordsWN[1].value
 
 static void ISPoll(void *);
 static void retryConnection(void *);
@@ -103,20 +101,12 @@ static ISwitchVectorProperty AlignmentSw= { mydev, "Alignment", "", COMM_GROUP,
 /************************************ GROUP: Main Control *************************************/
 /**********************************************************************************************/
 
-/********************************************
- Property: Equatorial Coordinates JNow
- Perm: Transient WO.
- Timeout: 120 seconds.
-*********************************************/
-INumber EquatorialCoordsWN[] 		= { {"RA",  "RA  H:M:S", "%10.6m",  0., 24., 0., 0., 0, 0, 0}, {"DEC", "Dec D:M:S", "%10.6m", -90., 90., 0., 0., 0, 0, 0} };
-INumberVectorProperty EquatorialCoordsWNP= { mydev, "EQUATORIAL_EOD_COORD_REQUEST", "Equatorial JNow", BASIC_GROUP, IP_WO, 120, IPS_IDLE, EquatorialCoordsWN, NARRAY(EquatorialCoordsWN), "", 0};
-
 /********************************************
  Property: Equatorial Coordinates JNow
  Perm: RO
 *********************************************/
 INumber EquatorialCoordsRN[]	 	= { {"RA",  "RA  H:M:S", "%10.6m",  0., 24., 0., 0., 0, 0, 0}, {"DEC", "Dec D:M:S", "%10.6m", -90., 90., 0., 0., 0, 0, 0}};
-INumberVectorProperty EquatorialCoordsRNP= { mydev, "EQUATORIAL_EOD_COORD", "Equatorial JNow", BASIC_GROUP, IP_RO, 120, IPS_IDLE, EquatorialCoordsRN, NARRAY(EquatorialCoordsRN), "", 0};
+INumberVectorProperty EquatorialCoordsRNP= { mydev, "EQUATORIAL_EOD_COORD", "Equatorial JNow", BASIC_GROUP, IP_RW, 120, IPS_IDLE, EquatorialCoordsRN, NARRAY(EquatorialCoordsRN), "", 0};
 
 /********************************************
  Property: On Coord Set
@@ -171,13 +161,13 @@ ISwitchVectorProperty MovementWESP      = { mydev, "TELESCOPE_MOTION_WE", "West/
 /********************************************
  Property: Timed Guide movement. North/South
 *********************************************/
-static INumber GuideNSN[]       = {{"TIMED_GUIDE_N", "North (sec)", "%g", 0, 10, 0.001, 0, 0, 0}, {"TIMED_GUIDE_S", "South (sec)", "%g", 0, 10, 0.001, 0, 0, 0}};
+static INumber GuideNSN[]       = {{"TIMED_GUIDE_N", "North (ms)", "%g", 0, 10, 0.001, 0, 0, 0}, {"TIMED_GUIDE_S", "South (ms)", "%g", 0, 10000, 100, 100, 0, 0}};
 INumberVectorProperty GuideNSNP      = { mydev, "TELESCOPE_TIMED_GUIDE_NS", "Guide North/South", MOTION_GROUP, IP_RW, 0, IPS_IDLE, GuideNSN, NARRAY(GuideNSN), "", 0};
 
 /********************************************
  Property: Timed Guide movement. West/East
 *********************************************/
-static INumber GuideWEN[]       = {{"TIMED_GUIDE_W", "West (sec)", "%g", 0, 10, 0.001, 0, 0, 0}, {"TIMED_GUIDE_E", "East (sec)", "%g", 0, 10, 0.001, 0, 0, 0}};
+static INumber GuideWEN[]       = {{"TIMED_GUIDE_W", "West (ms)", "%g", 0, 10, 0.001, 0, 0, 0}, {"TIMED_GUIDE_E", "East (ms)", "%g", 0, 10000, 100, 100, 0, 0}};
 INumberVectorProperty GuideWENP      = { mydev, "TELESCOPE_TIMED_GUIDE_WE", "Guide West/East", MOTION_GROUP, IP_RW, 0, IPS_IDLE, GuideWEN, NARRAY(GuideWEN), "", 0};
 
 /********************************************
@@ -290,7 +280,6 @@ void changeLX200GenericDeviceName(const char * newName)
   strcpy(AlignmentSw.device, newName);
 
   // BASIC_GROUP
-  strcpy(EquatorialCoordsWNP.device, newName);
   strcpy(EquatorialCoordsRNP.device, newName);
   strcpy(OnCoordSetSP.device , newName );
   strcpy(AbortSlewSP.device , newName );
@@ -356,7 +345,7 @@ void ISInit()
   
   if (strstr(me, "indi_lx200classic"))
   {
-     fprintf(stderr , "initilizaing from LX200 classic device...\n");
+     fprintf(stderr , "initializing from LX200 classic device...\n");
 
      telescope = new LX200Classic();
      if (envDev != NULL)
@@ -376,7 +365,7 @@ void ISInit()
 
   else if (strstr(me, "indi_lx200gps"))
   {
-     fprintf(stderr , "initilizaing from LX200 GPS device...\n");
+     fprintf(stderr , "initializing from LX200 GPS device...\n");
 
      // 2. device = sub_class
      telescope = new LX200GPS();
@@ -401,7 +390,7 @@ void ISInit()
   else if (strstr(me, "indi_lx200_16"))
   {
 
-    IDLog("Initilizaing from LX200 16 device...\n");
+    IDLog("Initializing from LX200 16 device...\n");
 
     // 2. device = sub_class
    telescope = new LX200_16();
@@ -422,7 +411,7 @@ void ISInit()
  }
  else if (strstr(me, "indi_lx200autostar"))
  {
-   fprintf(stderr , "initilizaing from autostar device...\n");
+   fprintf(stderr , "initializing from autostar device...\n");
   
    // 2. device = sub_class
    telescope = new LX200Autostar();
@@ -444,7 +433,7 @@ void ISInit()
  }
  else if (strstr(me, "indi_lx200ap"))
  {
-   fprintf(stderr , "initilizaing from ap device...\n");
+   fprintf(stderr , "initializing from ap device...\n");
   
 
    // 2. device = sub_class
@@ -468,7 +457,7 @@ void ISInit()
  }
  else if (strstr(me, "indi_lx200fs2"))
  {
-   fprintf(stderr , "initilizaing from fs2 device...\n");
+   fprintf(stderr , "initializing from fs2 device...\n");
   
    // 2. device = sub_class
    telescope = new LX200Fs2();
@@ -506,11 +495,11 @@ void ISInit()
   }
 
  }
-
+ IEAddTimer (POLLMS, ISPoll, NULL);
 }
 
 void ISGetProperties (const char *dev)
-{ ISInit(); telescope->ISGetProperties(dev); IEAddTimer (POLLMS, ISPoll, NULL);}
+{ ISInit(); telescope->ISGetProperties(dev);}
 void ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n)
 { ISInit(); telescope->ISNewSwitch(dev, name, states, names, n);}
 void ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n)
@@ -553,10 +542,10 @@ LX200Generic::LX200Generic()
 
    // Children call parent routines, this is the default
    IDLog("INDI Library v%g\n", INDI_LIBV);
-   IDLog("initilizaing from generic LX200 device...\n");
-   IDLog("Driver Version: 2008-05-21\n");
+   IDLog("initializing from generic LX200 device...\n");
+   IDLog("Driver Version: 2012-07-27\n");
  
-   //enableSimulation(true);  
+   //enableSimulation(true);
 }
 
 LX200Generic::~LX200Generic()
@@ -580,7 +569,6 @@ void LX200Generic::ISGetProperties(const char *dev)
   IDDefSwitch (&AlignmentSw, NULL);
 
   // BASIC_GROUP
-  IDDefNumber (&EquatorialCoordsWNP, NULL);
   IDDefNumber (&EquatorialCoordsRNP, NULL);
   IDDefSwitch (&OnCoordSetSP, NULL);
   IDDefSwitch (&AbortSlewSP, NULL);
@@ -794,21 +782,21 @@ void LX200Generic::ISNewNumber (const char *dev, const char *name, double values
 	}
 	#endif
 
-	if (!strcmp (name, EquatorialCoordsWNP.name))
+    if (!strcmp (name, EquatorialCoordsRNP.name))
 	{
 	  int i=0, nset=0;
 
-	  if (checkPower(&EquatorialCoordsWNP))
+      if (checkPower(&EquatorialCoordsRNP))
 	   return;
 
 	    for (nset = i = 0; i < n; i++)
 	    {
-		INumber *eqp = IUFindNumber (&EquatorialCoordsWNP, names[i]);
-		if (eqp == &EquatorialCoordsWN[0])
+        INumber *eqp = IUFindNumber (&EquatorialCoordsRNP, names[i]);
+        if (eqp == &EquatorialCoordsRN[0])
 		{
                     newRA = values[i];
 		    nset += newRA >= 0 && newRA <= 24.0;
-		} else if (eqp == &EquatorialCoordsWN[1])
+        } else if (eqp == &EquatorialCoordsRN[1])
 		{
 		    newDEC = values[i];
 		    nset += newDEC >= -90.0 && newDEC <= 90.0;
@@ -831,28 +819,28 @@ void LX200Generic::ISNewNumber (const char *dev, const char *name, double values
 	  if (!simulation)
 	   if ( (err = setObjectRA(fd, newRA)) < 0 || ( err = setObjectDEC(fd, newDEC)) < 0)
 	   {
-	     EquatorialCoordsWNP.s = IPS_ALERT ;
-	     IDSetNumber(&EquatorialCoordsWNP, NULL);
-	     handleError(&EquatorialCoordsWNP, err, "Setting RA/DEC");
+         EquatorialCoordsRNP.s = IPS_ALERT ;
+         IDSetNumber(&EquatorialCoordsRNP, NULL);
+         handleError(&EquatorialCoordsRNP, err, "Setting RA/DEC");
 	     return;
 	   } 
 	   /* wildi In principle this line is according to the discussion */
 	   /* In case the telescope is slewing, we have to abort that. No status change here */
            /* EquatorialCoordsWNP.s = IPS_OK; */
-           IDSetNumber(&EquatorialCoordsWNP, NULL);
+           IDSetNumber(&EquatorialCoordsRNP, NULL);
 	   targetRA  = newRA;
 	   targetDEC = newDEC;
 
 	   if (handleCoordSet())
 	   {
-	     EquatorialCoordsWNP.s = IPS_ALERT;
-	     IDSetNumber(&EquatorialCoordsWNP, NULL);
+         EquatorialCoordsRNP.s = IPS_ALERT;
+         IDSetNumber(&EquatorialCoordsRNP, NULL);
 	   }
 	} // end nset
 	else
 	{
-		EquatorialCoordsWNP.s = IPS_ALERT;
-		IDSetNumber(&EquatorialCoordsWNP, "RA or Dec missing or invalid");
+        EquatorialCoordsRNP.s = IPS_ALERT;
+        IDSetNumber(&EquatorialCoordsRNP, "RA or Dec missing or invalid");
 	}
 
 	    return;
@@ -873,11 +861,11 @@ void LX200Generic::ISNewNumber (const char *dev, const char *name, double values
 	  }
 
 	  getSexComponents(values[0], &h, &m, &s);
-	  IDLog("Siderial Time is %02d:%02d:%02d\n", h, m, s);
+	  IDLog("Sidereal Time is %02d:%02d:%02d\n", h, m, s);
 	  
 	  if ( ( err = setSDTime(fd, h, m, s) < 0) )
 	  {
-	    handleError(&SDTimeNP, err, "Setting siderial time"); 
+	    handleError(&SDTimeNP, err, "Setting sidereal time"); 
             return;
 	  }
 	  
@@ -1080,10 +1068,10 @@ void LX200Generic::ISNewNumber (const char *dev, const char *name, double values
 	  IUUpdateNumber(&GuideWENP, values, names, n);
 
 	  if (GuideWENP.np[0].value > 0) {
-		duration_msec = GuideWENP.np[0].value * 1000;
+        duration_msec = GuideWENP.np[0].value;
 		direction = LX200_WEST;
 	  } else {
-		duration_msec = GuideWENP.np[1].value * 1000;
+        duration_msec = GuideWENP.np[1].value;
 		direction = LX200_EAST;
 	  }
 	  if (duration_msec <= 0) {
@@ -1159,26 +1147,26 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	  }
 	  
 	  IUResetSwitch(&AbortSlewSP);
-	  if (abortSlew(fd) < 0)
+      if (!simulation && abortSlew(fd) < 0)
 	  {
 		AbortSlewSP.s = IPS_ALERT;
 		IDSetSwitch(&AbortSlewSP, NULL);
 		return;
 	  }
 
-	    if (EquatorialCoordsWNP.s == IPS_BUSY)
+        if (EquatorialCoordsRNP.s == IPS_BUSY)
 	    {
 		AbortSlewSP.s = IPS_OK;
-		EquatorialCoordsWNP.s       = IPS_IDLE;
+        EquatorialCoordsRNP.s       = IPS_IDLE;
 		IDSetSwitch(&AbortSlewSP, "Slew aborted.");
-		IDSetNumber(&EquatorialCoordsWNP, NULL);
+        IDSetNumber(&EquatorialCoordsRNP, NULL);
             }
 	    else if (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY)
 	    {
 		MovementNSSP.s  = MovementWESP.s =  IPS_IDLE; 
 	
 		AbortSlewSP.s = IPS_OK;		
-		EquatorialCoordsWNP.s       = IPS_IDLE;
+        EquatorialCoordsRNP.s       = IPS_IDLE;
 		IUResetSwitch(&MovementNSSP);
 		IUResetSwitch(&MovementWESP);
 		IUResetSwitch(&AbortSlewSP);
@@ -1186,7 +1174,7 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 		IDSetSwitch(&AbortSlewSP, "Slew aborted.");
 		IDSetSwitch(&MovementNSSP, NULL);
 		IDSetSwitch(&MovementWESP, NULL);
-		IDSetNumber(&EquatorialCoordsWNP, NULL);
+        IDSetNumber(&EquatorialCoordsRNP, NULL);
 	    }
 	    else if (GuideNSNP.s == IPS_BUSY || GuideWENP.s == IPS_BUSY)
 	    {
@@ -1203,13 +1191,13 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 		}
 
 		AbortSlewSP.s = IPS_OK;
-		EquatorialCoordsWNP.s       = IPS_IDLE;
+        EquatorialCoordsRNP.s       = IPS_IDLE;
 		IUResetSwitch(&AbortSlewSP);
 
 		IDSetSwitch(&AbortSlewSP, "Guide aborted.");
 		IDSetNumber(&GuideNSNP, NULL);
 		IDSetNumber(&GuideWENP, NULL);
-		IDSetNumber(&EquatorialCoordsWNP, NULL);
+        IDSetNumber(&EquatorialCoordsRNP, NULL);
 	    }
 	    else
 	    {
@@ -1738,8 +1726,7 @@ void LX200Generic::guideTimeout(void *p)
 
 void LX200Generic::ISPoll()
 {
-        double dx, dy;
-	/*static int okCounter = 3;*/
+    double dx, dy;
 	int err=0;
 	
 	if (!isTelescopeOn())
@@ -1749,7 +1736,7 @@ void LX200Generic::ISPoll()
 	{
 		mountSim();
 		return;
-        }
+	}
 
 	if ( (err = getLX200RA(fd, &currentRA)) < 0 || (err = getLX200DEC(fd, &currentDEC)) < 0)
 	{
@@ -1762,21 +1749,19 @@ void LX200Generic::ISPoll()
 	if (fault)
 	  correctFault();
 
-	EquatorialCoordsRNP.s = IPS_OK;
-
-	if ( fabs(lastRA - currentRA) > (SlewAccuracyN[0].value/(60.0*15.0)) || fabs(lastDEC - currentDEC) > (SlewAccuracyN[1].value/60.0))
-	{
-	  	lastRA  = currentRA;
-		lastDEC = currentDEC;
-		IDSetNumber (&EquatorialCoordsRNP, NULL);
-	}
-
-	switch (EquatorialCoordsWNP.s)
+    switch (EquatorialCoordsRNP.s)
 	{
 	case IPS_IDLE:
+    case IPS_OK:
+        if ( fabs(lastRA - currentRA) > (SlewAccuracyN[0].value/(60.0*15.0)) || fabs(lastDEC - currentDEC) > (SlewAccuracyN[1].value/60.0))
+        {
+            lastRA  = currentRA;
+            lastDEC = currentDEC;
+            IDSetNumber (&EquatorialCoordsRNP, NULL);
+        }
         break;
 
-        case IPS_BUSY:
+	case IPS_BUSY:
 	    dx = targetRA - currentRA;
 	    dy = targetDEC - currentDEC;
 
@@ -1786,21 +1771,17 @@ void LX200Generic::ISPoll()
 	       lastRA  = currentRA;
 	       lastDEC = currentDEC;
 	       
-	       EquatorialCoordsWNP.s = IPS_OK;
-	       IDSetNumber(&EquatorialCoordsWNP, "Slew is complete, target locked...");
-	       
-	    break;
-
-	case IPS_OK:
-        break;
-
+           EquatorialCoordsRNP.s = IPS_OK;
+           IDSetNumber(&EquatorialCoordsRNP, "Slew is complete, target locked...");
+		}  
+		break;
 
 	case IPS_ALERT:
 	    break;
 	}
 }
 
-}
+
 // wildi nothing changed in LX200Generic::mountSim
 void LX200Generic::mountSim ()
 {
@@ -1820,7 +1801,7 @@ void LX200Generic::mountSim ()
 	da = SLEWRATE*dt;
 
 	/* Process per current state. We check the state of EQUATORIAL_COORDS and act acoordingly */
-	switch (EquatorialCoordsWNP.s)
+    switch (EquatorialCoordsRNP.s)
 	{
 	
 	/* #1 State is idle, update telesocpe at sidereal rate */
@@ -1863,9 +1844,7 @@ void LX200Generic::mountSim ()
 	    if (nlocked == 2)
 	    {
 		EquatorialCoordsRNP.s = IPS_OK;
-		EquatorialCoordsWNP.s = IPS_OK;
-		IDSetNumber(&EquatorialCoordsWNP, "Now tracking");
-		IDSetNumber(&EquatorialCoordsRNP, NULL);
+        IDSetNumber(&EquatorialCoordsRNP, "Now tracking");
 	    } else
 		IDSetNumber(&EquatorialCoordsRNP, NULL);
 
@@ -1959,12 +1938,12 @@ int LX200Generic::handleCoordSet()
     // Slew
     case LX200_TRACK:
           lastSet = LX200_TRACK;
-	  if (EquatorialCoordsWNP.s == IPS_BUSY)
+      if (EquatorialCoordsRNP.s == IPS_BUSY)
 	  {
 	     #ifdef INDI_DEBUG
-	     IDLog("Aboring Slew\n");
+	     IDLog("Aborting Slew\n");
 	     #endif
-	     if (abortSlew(fd) < 0)
+         if (!simulation && abortSlew(fd) < 0)
 	     {
 		AbortSlewSP.s = IPS_ALERT;
 		IDSetSwitch(&AbortSlewSP, NULL);
@@ -1973,14 +1952,14 @@ int LX200Generic::handleCoordSet()
 	     }
 
 	     AbortSlewSP.s = IPS_OK;
-	     EquatorialCoordsWNP.s       = IPS_IDLE;
-             IDSetSwitch(&AbortSlewSP, "Slew aborted.");
-	     IDSetNumber(&EquatorialCoordsWNP, NULL);
+         EquatorialCoordsRNP.s       = IPS_IDLE;
+         IDSetSwitch(&AbortSlewSP, "Slew aborted.");
+         IDSetNumber(&EquatorialCoordsRNP, NULL);
 
 	     if (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY)
 	     {
 		MovementNSSP.s  = MovementWESP.s =  IPS_IDLE; 
-		EquatorialCoordsWNP.s       = IPS_IDLE;
+        EquatorialCoordsRNP.s       = IPS_IDLE;
 		IUResetSwitch(&MovementNSSP);
 		IUResetSwitch(&MovementWESP);
 		IUResetSwitch(&AbortSlewSP);
@@ -1993,17 +1972,17 @@ int LX200Generic::handleCoordSet()
 	usleep(100000);
 	}
 
-	if ((err = Slew(fd))) /* Slew reads the '0', that is not the end of the slew */
+    if (!simulation && (err = Slew(fd))) /* Slew reads the '0', that is not the end of the slew */
 	{
 	    IDMessage(mydev "ERROR Slewing to JNow RA %s - DEC %s\n", RAStr, DecStr);
 	    slewError(err);
 	    return  -1;
 	}
 
-	EquatorialCoordsWNP.s = IPS_BUSY;
+    EquatorialCoordsRNP.s = IPS_BUSY;
 	fs_sexa(RAStr, targetRA, 2, 3600);
 	fs_sexa(DecStr, targetDEC, 2, 3600);
-	IDSetNumber(&EquatorialCoordsWNP, "Slewing to JNow RA %s - DEC %s", RAStr, DecStr);
+    IDSetNumber(&EquatorialCoordsRNP, "Slewing to JNow RA %s - DEC %s", RAStr, DecStr);
 	#ifdef INDI_DEBUG
 	IDLog("Slewing to JNow RA %s - DEC %s\n", RAStr, DecStr);
         #endif
@@ -2016,14 +1995,16 @@ int LX200Generic::handleCoordSet()
 	if (!simulation)
 	  if ( ( err = Sync(fd, syncString) < 0) )
 	  {
-		EquatorialCoordsWNP.s = IPS_ALERT;
-	        IDSetNumber(&EquatorialCoordsWNP , "Synchronization failed.");
+        EquatorialCoordsRNP.s = IPS_ALERT;
+            IDSetNumber(&EquatorialCoordsRNP , "Synchronization failed.");
 		return (-1);
 	  }
 
-	  EquatorialCoordsWNP.s = IPS_OK;
+    EquatorialCoordsRN[0].value = targetRA;
+    EquatorialCoordsRN[1].value = targetDEC;
+      EquatorialCoordsRNP.s = IPS_OK;
 	  IDLog("Synchronization successful %s\n", syncString);
-	  IDSetNumber(&EquatorialCoordsWNP, "Synchronization successful.");
+      IDSetNumber(&EquatorialCoordsRNP, "Synchronization successful.");
 	  break;
 	  
    }
@@ -2116,6 +2097,7 @@ void LX200Generic::connectTelescope()
 	  return;
 	}
 	
+	 tty_disconnect(fd); // Close if already open
 	 if (tty_connect(PortTP.tp[0].text, 9600, 8, 0, 1, &fd) != TTY_OK)
 	 {
 	   ConnectS[0].s = ISS_OFF;
@@ -2132,7 +2114,7 @@ void LX200Generic::connectTelescope()
 	 }
 
         #ifdef INDI_DEBUG
-        IDLog("Telescope test successfful.\n");
+        IDLog("Telescope test successful.\n");
 	#endif
 
         *((int *) UTCOffsetN[0].aux0) = 0;
@@ -2156,14 +2138,14 @@ void LX200Generic::connectTelescope()
 
 void LX200Generic::slewError(int slewCode)
 {
-    EquatorialCoordsWNP.s = IPS_ALERT;
+    EquatorialCoordsRNP.s = IPS_ALERT;
 
     if (slewCode == 1)
-	IDSetNumber(&EquatorialCoordsWNP, "Object below horizon.");
+    IDSetNumber(&EquatorialCoordsRNP, "Object below horizon.");
     else if (slewCode == 2)
-	IDSetNumber(&EquatorialCoordsWNP, "Object below the minimum elevation limit.");
+    IDSetNumber(&EquatorialCoordsRNP, "Object below the minimum elevation limit.");
     else
-	IDSetNumber(&EquatorialCoordsWNP, "Slew failed.");
+    IDSetNumber(&EquatorialCoordsRNP, "Slew failed.");
 
 }
 
@@ -2244,7 +2226,7 @@ void LX200Generic::updateTime()
   getSexComponents(ctime, &h, &m, &s);
 
   if ( (result = getSDTime(fd, &SDTimeN[0].value)) < 0)
-    IDMessage(thisDevice, "Failed to retrieve siderial time from device.");
+    IDMessage(thisDevice, "Failed to retrieve sidereal time from device.");
   
   getCalenderDate(fd, cdate);
   result = sscanf(cdate, "%d/%d/%d", &year, &month, &day);
