@@ -25,6 +25,9 @@
 class SynscanMount : public INDI::Telescope
 {
     protected:
+
+    bool canPark();
+
     private:
     public:
         SynscanMount();
@@ -39,6 +42,7 @@ class SynscanMount : public INDI::Telescope
         bool ReadScopeStatus();
         bool Goto(double,double);
         bool Park();
+        bool Abort();
 
 
 };
