@@ -97,14 +97,6 @@ ScopeSim::ScopeSim()
     currentDEC=15;
     Parked=false;
 
-    GuideNSNP = new INumberVectorProperty;
-    GuideWENP = new INumberVectorProperty;
-    EqPECNV = new INumberVectorProperty;
-    GuideRateNP = new INumberVectorProperty;
-
-    PECErrNSSP = new ISwitchVectorProperty;
-    PECErrWESP = new ISwitchVectorProperty;
-
     /* initialize random seed: */
       srand ( time(NULL) );
 }
@@ -124,35 +116,35 @@ bool ScopeSim::initProperties()
     /* Make sure to init parent properties first */
     INDI::Telescope::initProperties();
 
-    /* Property for guider support. How many seconds to guide either northward or southward? */
-    IUFillNumber(&GuideNSN[GUIDE_NORTH], "TIMED_GUIDE_N", "North (sec)", "%g", 0, 10, 0.001, 0);
-    IUFillNumber(&GuideNSN[GUIDE_SOUTH], "TIMED_GUIDE_S", "South (sec)", "%g", 0, 10, 0.001, 0);
-    IUFillNumberVector(GuideNSNP, GuideNSN, 2, deviceName(), "TELESCOPE_TIMED_GUIDE_NS", "Guide North/South", MOTION_TAB, IP_RW, 0, IPS_IDLE);
-
-    /* Property for guider support. How many seconds to guide either westward or eastward? */
-    IUFillNumber(&GuideWEN[GUIDE_WEST], "TIMED_GUIDE_W", "West (sec)", "%g", 0, 10, 0.001, 0);
-    IUFillNumber(&GuideWEN[GUIDE_EAST], "TIMED_GUIDE_E", "East (sec)", "%g", 0, 10, 0.001, 0);
-    IUFillNumberVector(GuideWENP, GuideWEN, 2, deviceName(), "TELESCOPE_TIMED_GUIDE_WE", "Guide West/East", MOTION_TAB, IP_RW, 0, IPS_IDLE);
-
     /* Simulated periodic error in RA, DEC */
     IUFillNumber(&EqPECN[RA_AXIS],"RA_PEC","RA (hh:mm:ss)","%010.6m",0,24,0,15.);
     IUFillNumber(&EqPECN[DEC_AXIS],"DEC_PEC","DEC (dd:mm:ss)","%010.6m",-90,90,0,15.);
-    IUFillNumberVector(EqPECNV,EqPECN,2,deviceName(),"EQUATORIAL_PEC","Periodic Error",MOTION_TAB,IP_RO,60,IPS_IDLE);
+    IUFillNumberVector(&EqPECNV,EqPECN,2,getDeviceName(),"EQUATORIAL_PEC","Periodic Error",MOTION_TAB,IP_RO,60,IPS_IDLE);
 
     /* Enable client to manually add periodic error northward or southward for simulation purposes */
     IUFillSwitch(&PECErrNSS[MOTION_NORTH], "PEC_N", "North", ISS_OFF);
     IUFillSwitch(&PECErrNSS[MOTION_SOUTH], "PEC_S", "South", ISS_OFF);
-    IUFillSwitchVector(PECErrNSSP, PECErrNSS, 2, deviceName(),"PEC_NS", "PE N/S", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitchVector(&PECErrNSSP, PECErrNSS, 2, getDeviceName(),"PEC_NS", "PE N/S", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
 
     /* Enable client to manually add periodic error westward or easthward for simulation purposes */
     IUFillSwitch(&PECErrWES[MOTION_WEST], "PEC_W", "West", ISS_OFF);
     IUFillSwitch(&PECErrWES[MOTION_EAST], "PEC_E", "East", ISS_OFF);
-    IUFillSwitchVector(PECErrWESP, PECErrWES, 2, deviceName(),"PEC_WE", "PE W/E", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitchVector(&PECErrWESP, PECErrWES, 2, getDeviceName(),"PEC_WE", "PE W/E", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
 
-    /* How fast do we guide compared to sideral rate */
+    /* How fast do we guide compared to sidereal rate */
     IUFillNumber(&GuideRateN[RA_AXIS], "GUIDE_RATE_WE", "W/E Rate", "%g", 0, 1, 0.1, 0.3);
     IUFillNumber(&GuideRateN[DEC_AXIS], "GUIDE_RATE_NS", "N/S Rate", "%g", 0, 1, 0.1, 0.3);
-    IUFillNumberVector(GuideRateNP, GuideRateN, 2, deviceName(), "GUIDE_RATE", "Guiding Rate", MOTION_TAB, IP_RW, 0, IPS_IDLE);
+    IUFillNumberVector(&GuideRateNP, GuideRateN, 2, getDeviceName(), "GUIDE_RATE", "Guiding Rate", MOTION_TAB, IP_RW, 0, IPS_IDLE);
+
+    // Let's simulate it to be an F/10 8" telescope
+    ScopeParametersN[0].value = 203;
+    ScopeParametersN[1].value = 2000;
+    ScopeParametersN[2].value = 203;
+    ScopeParametersN[3].value = 2000;
+
+    TrackState=SCOPE_IDLE;
+
+    initGuiderProperties(getDeviceName(), MOTION_TAB);
 
     /* Add debug controls so we may debug driver if necessary */
     addDebugControl();
@@ -167,12 +159,12 @@ void ScopeSim::ISGetProperties (const char *dev)
 
     if(isConnected())
     {
-        defineNumber(GuideNSNP);
-        defineNumber(GuideWENP);
-        defineNumber(GuideRateNP);
-        defineNumber(EqPECNV);
-        defineSwitch(PECErrNSSP);
-        defineSwitch(PECErrWESP);
+        defineNumber(&GuideNSP);
+        defineNumber(&GuideEWP);
+        defineNumber(&GuideRateNP);
+        defineNumber(&EqPECNV);
+        defineSwitch(&PECErrNSSP);
+        defineSwitch(&PECErrWESP);
     }
 
     return;
@@ -184,22 +176,22 @@ bool ScopeSim::updateProperties()
 
     if (isConnected())
     {
-        defineNumber(GuideNSNP);
-        defineNumber(GuideWENP);
-        defineNumber(GuideRateNP);
-        defineNumber(EqPECNV);
-        defineSwitch(PECErrNSSP);
-        defineSwitch(PECErrWESP);
+        defineNumber(&GuideNSP);
+        defineNumber(&GuideEWP);
+        defineNumber(&GuideRateNP);
+        defineNumber(&EqPECNV);
+        defineSwitch(&PECErrNSSP);
+        defineSwitch(&PECErrWESP);
 
     }
     else
     {
-        deleteProperty(GuideNSNP->name);
-        deleteProperty(GuideWENP->name);
-        deleteProperty(EqPECNV->name);
-        deleteProperty(PECErrNSSP->name);
-        deleteProperty(PECErrNSSP->name);
-        deleteProperty(GuideRateNP->name);
+        deleteProperty(GuideNSP.name);
+        deleteProperty(GuideEWP.name);
+        deleteProperty(EqPECNV.name);
+        deleteProperty(PECErrNSSP.name);
+        deleteProperty(PECErrWESP.name);
+        deleteProperty(GuideRateNP.name);
     }
 
     return true;
@@ -219,9 +211,9 @@ bool ScopeSim::Connect()
     return rc;
 }
 
-bool ScopeSim::Connect(char *)
+bool ScopeSim::Connect(char *port)
 {
-    return true;
+   return true;
 }
 
 bool ScopeSim::Disconnect()
@@ -262,7 +254,7 @@ bool ScopeSim::ReadScopeStatus()
     else
         da_dec = FINE_SLEW_RATE *dt;
 
-    switch (MovementNSSP->s)
+    switch (MovementNSSP.s)
     {
        case IPS_BUSY:
         if (MovementNSS[MOTION_NORTH].s == ISS_ON)
@@ -275,7 +267,7 @@ bool ScopeSim::ReadScopeStatus()
         break;
     }
 
-    switch (MovementWESP->s)
+    switch (MovementWESP.s)
     {
         case IPS_BUSY:
 
@@ -293,9 +285,9 @@ bool ScopeSim::ReadScopeStatus()
     /* Process per current state. We check the state of EQUATORIAL_EOD_COORDS_REQUEST and act acoordingly */
     switch (TrackState)
     {
-    case SCOPE_IDLE:
-        EqNV->s = IPS_IDLE;
-        break;
+    /*case SCOPE_IDLE:
+        EqNV.s = IPS_IDLE;
+        break;*/
     case SCOPE_SLEWING:
     case SCOPE_PARKING:
         /* slewing - nail it when both within one pulse @ SLEWRATE */
@@ -325,7 +317,7 @@ bool ScopeSim::ReadScopeStatus()
         else
           currentDEC -= da_dec;
 
-        EqNV->s = IPS_BUSY;
+        EqNV.s = IPS_BUSY;
 
         if (nlocked == 2)
         {
@@ -336,96 +328,82 @@ bool ScopeSim::ReadScopeStatus()
                 EqPECN[0].value = currentRA;
                 EqPECN[1].value = currentDEC;
 
-                IDSetNumber(EqPECNV, NULL);
+                IDSetNumber(&EqPECNV, NULL);
 
                 TrackState = SCOPE_TRACKING;
 
-                EqNV->s = IPS_OK;
-                IDMessage(deviceName(), "Telescope slew is complete. Tracking...");
+                EqNV.s = IPS_OK;
+                IDMessage(getDeviceName(), "Telescope slew is complete. Tracking...");
             }
             else
             {
                 TrackState = SCOPE_PARKED;
-                EqNV->s = IPS_IDLE;
-                IDMessage(deviceName(), "Telescope parked successfully.");
+                EqNV.s = IPS_IDLE;
+                IDMessage(getDeviceName(), "Telescope parked successfully.");
             }
         }
 
         break;
 
+    case SCOPE_IDLE:
     case SCOPE_TRACKING:
         /* tracking */
 
-        if (GuideNSN[GUIDE_NORTH].value > 0)
+        dt *= 1000;
+        if (guiderNSTarget[GUIDE_NORTH] > 0)
         {
             if (isDebug())
-                IDLog("  ****** Commanded to GUIDE NORTH for %g ms *****\n", GuideNSN[GUIDE_NORTH].value*1000);
+                IDLog("  ****** Commanded to GUIDE NORTH for %g ms *****\n", guiderNSTarget[GUIDE_NORTH]);
             ns_guide_dir = GUIDE_NORTH;
         }
-        else if (GuideNSN[GUIDE_SOUTH].value > 0)
+        else if (guiderNSTarget[GUIDE_SOUTH] > 0)
         {
             if (isDebug())
-                IDLog("  ****** Commanded to GUIDE SOUTH for %g ms *****\n", GuideNSN[GUIDE_SOUTH].value*1000);
+                IDLog("  ****** Commanded to GUIDE SOUTH for %g ms *****\n", guiderNSTarget[GUIDE_SOUTH]);
             ns_guide_dir = GUIDE_SOUTH;
         }
 
         // WE Guide Selection
-        if (GuideWEN[GUIDE_WEST].value > 0)
+        if (guiderEWTarget[GUIDE_WEST] > 0)
         {
             we_guide_dir = GUIDE_WEST;
             if (isDebug())
-            IDLog("  ****** Commanded to GUIDE WEST for %g ms ****** \n", GuideWEN[GUIDE_WEST].value*1000);
+            IDLog("  ****** Commanded to GUIDE WEST for %g ms ****** \n", guiderEWTarget[GUIDE_WEST]);
         }
-        else if (GuideWEN[GUIDE_EAST].value > 0)
+        else if (guiderEWTarget[GUIDE_EAST] > 0)
         {
             we_guide_dir = GUIDE_EAST;
             if (isDebug())
-               IDLog(" ****** Commanded to GUIDE EAST for %g ms  ****** \n", GuideWEN[GUIDE_EAST].value*1000);
+               IDLog(" ****** Commanded to GUIDE EAST for %g ms  ****** \n", guiderEWTarget[GUIDE_EAST]);
         }
 
         if (ns_guide_dir != -1)
         {
 
-            dec_guide_dt =  SID_RATE * GuideRateN[DEC_AXIS].value * GuideNSN[ns_guide_dir].value * (ns_guide_dir==GUIDE_NORTH ? 1 : -1);
+            dec_guide_dt =  SID_RATE * GuideRateN[DEC_AXIS].value * guiderNSTarget[ns_guide_dir]/1000.0 * (ns_guide_dir==GUIDE_NORTH ? 1 : -1);
 
             // If time remaining is more that dt, then decrement and
-          if (GuideNSN[ns_guide_dir].value >= dt)
-              GuideNSN[ns_guide_dir].value -= dt;
+          if (guiderNSTarget[ns_guide_dir] >= dt)
+              guiderNSTarget[ns_guide_dir] -= dt;
           else              
-              GuideNSN[ns_guide_dir].value = 0;
+              guiderNSTarget[ns_guide_dir] = 0;
 
           EqPECN[DEC_AXIS].value += dec_guide_dt;
 
-            if (GuideNSN[ns_guide_dir].value <= 0)
-            {
-                GuideNSN[GUIDE_NORTH].value = GuideNSN[GUIDE_SOUTH].value = 0;
-                GuideNSNP->s = IPS_OK;
-                IDSetNumber(GuideNSNP, NULL);
-            }
-            else
-                IDSetNumber(GuideNSNP, NULL);
           }
 
         if (we_guide_dir != -1)
         {
 
-            ra_guide_dt = SID_RATE/15.0 * GuideRateN[RA_AXIS].value * GuideWEN[we_guide_dir].value* (we_guide_dir==GUIDE_WEST ? -1 : 1);
+            ra_guide_dt = SID_RATE/15.0 * GuideRateN[RA_AXIS].value * guiderEWTarget[we_guide_dir]/1000.0 * (we_guide_dir==GUIDE_WEST ? -1 : 1);
 
-          if (GuideWEN[we_guide_dir].value >= dt)
-                GuideWEN[we_guide_dir].value -= dt;
+          if (guiderEWTarget[we_guide_dir] >= dt)
+                guiderEWTarget[we_guide_dir] -= dt;
           else
-                GuideWEN[we_guide_dir].value = 0;
+                guiderEWTarget[we_guide_dir] = 0;
 
           EqPECN[RA_AXIS].value += ra_guide_dt;
 
-            if (GuideWEN[we_guide_dir].value <= 0)
-            {
-                GuideWEN[GUIDE_WEST].value = GuideWEN[GUIDE_EAST].value = 0;
-                GuideWENP->s = IPS_OK;
-                IDSetNumber(GuideWENP, NULL);
-            }
-            else
-                IDSetNumber(GuideWENP, NULL);
           }
 
 
@@ -464,7 +442,7 @@ bool ScopeSim::ReadScopeStatus()
         }
 
         if (ns_guide_dir != -1 || we_guide_dir != -1)
-            IDSetNumber(EqPECNV, NULL);
+            IDSetNumber(&EqPECNV, NULL);
 
          break;
 
@@ -489,10 +467,29 @@ bool ScopeSim::Goto(double r,double d)
     Parked=false;
     TrackState = SCOPE_SLEWING;
 
-    EqReqNV->s = IPS_BUSY;
-    EqNV->s    = IPS_BUSY;
+    EqNV.s    = IPS_BUSY;
+
+    IDMessage(getDeviceName(), "Slewing to RA: %s - DEC: %s", RAStr, DecStr);
+    return true;
+}
+
+bool ScopeSim::Sync(double ra, double dec)
+{
+    currentRA  = ra;
+    currentDEC = dec;
+
+    EqPECN[RA_AXIS].value = ra;
+    EqPECN[DEC_AXIS].value = dec;
+    IDSetNumber(&EqPECNV, NULL);
+
+    IDMessage(getDeviceName(), "Sync is successful.");
+
+    TrackState = SCOPE_IDLE;
+    EqNV.s    = IPS_OK;
+
+
+    NewRaDec(currentRA, currentDEC);
 
-    IDMessage(deviceName(), "Slewing to RA: %s - DEC: %s", RAStr, DecStr);
     return true;
 }
 
@@ -502,7 +499,7 @@ bool ScopeSim::Park()
     targetDEC=90;
     Parked=true;
     TrackState = SCOPE_PARKING;
-    IDMessage(deviceName(), "Parking telescope in progress...");
+    IDMessage(getDeviceName(), "Parking telescope in progress...");
     return true;
 }
 
@@ -510,51 +507,26 @@ bool ScopeSim::ISNewNumber (const char *dev, const char *name, double values[],
 {
     //  first check if it's for our device
 
-    if(strcmp(dev,deviceName())==0)
+    if(strcmp(dev,getDeviceName())==0)
     {
-        //  This is for our device
-        //  Now lets see if it's something we process here
-         if(strcmp(name,"TELESCOPE_TIMED_GUIDE_NS")==0)
-         {
-
-             // Unless we're in track mode, we don't obey guide commands.
-             if (TrackState != SCOPE_TRACKING)
-             {
-                 GuideNSNP->s = IPS_IDLE;
-                 IDSetNumber(GuideNSNP, NULL);
-                 return true;
-             }
-
-             IUUpdateNumber(GuideNSNP, values, names, n);
-
-           return true;
-         }
-
-         if(strcmp(name,"TELESCOPE_TIMED_GUIDE_WE")==0)
-         {
-             // Unless we're in track mode, we don't obey guide commands.
-             if (TrackState != SCOPE_TRACKING)
-             {
-                 GuideWENP->s = IPS_IDLE;
-                 IDSetNumber(GuideWENP, NULL);
-                 return true;
-             }
-
-             IUUpdateNumber(GuideWENP, values, names, n);
-
-           return true;
-         }
-
          if(strcmp(name,"GUIDE_RATE")==0)
          {
-             IUUpdateNumber(GuideRateNP, values, names, n);
-             GuideRateNP->s = IPS_OK;
-             IDSetNumber(GuideRateNP, NULL);
+             IUUpdateNumber(&GuideRateNP, values, names, n);
+             GuideRateNP.s = IPS_OK;
+             IDSetNumber(&GuideRateNP, NULL);
+             return true;
+         }
+
+         if (!strcmp(name,GuideNSP.name) || !strcmp(name,GuideEWP.name))
+         {
+             processGuiderProperties(name, values, names, n);
              return true;
          }
 
     }
 
+
+
     //  if we didn't process it, continue up the chain, let somebody else
     //  give it a shot
     return INDI::Telescope::ISNewNumber(dev,name,values,names,n);
@@ -567,13 +539,13 @@ bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
     //    IDLog("Switch %s %d\n",names[x],states[x]);
     //}
 
-    if(strcmp(dev,deviceName())==0)
+    if(strcmp(dev,getDeviceName())==0)
     {
         if(strcmp(name,"PEC_NS")==0)
         {
-            IUUpdateSwitch(PECErrNSSP,states,names,n);
+            IUUpdateSwitch(&PECErrNSSP,states,names,n);
 
-            PECErrNSSP->s = IPS_OK;
+            PECErrNSSP.s = IPS_OK;
 
             if (PECErrNSS[MOTION_NORTH].s == ISS_ON)
             {
@@ -588,9 +560,9 @@ bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
                     IDLog("$$$$$ Simulating PE in SOUTH direction for value of %g $$$$$\n", SID_RATE);
             }
 
-            IUResetSwitch(PECErrNSSP);
-            IDSetSwitch(PECErrNSSP, NULL);
-            IDSetNumber(EqPECNV, NULL);
+            IUResetSwitch(&PECErrNSSP);
+            IDSetSwitch(&PECErrNSSP, NULL);
+            IDSetNumber(&EqPECNV, NULL);
 
             return true;
 
@@ -598,9 +570,9 @@ bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
 
         if(strcmp(name,"PEC_WE")==0)
         {
-            IUUpdateSwitch(PECErrWESP,states,names,n);
+            IUUpdateSwitch(&PECErrWESP,states,names,n);
 
-            PECErrWESP->s = IPS_OK;
+            PECErrWESP.s = IPS_OK;
 
             if (PECErrWES[MOTION_WEST].s == ISS_ON)
             {
@@ -615,9 +587,9 @@ bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
                     IDLog("$$$$$$ Simulator PE in EAST direction for value of %g $$$$$$\n", SID_RATE);
             }
 
-            IUResetSwitch(PECErrWESP);
-            IDSetSwitch(PECErrWESP, NULL);
-            IDSetNumber(EqPECNV, NULL);
+            IUResetSwitch(&PECErrWESP);
+            IDSetSwitch(&PECErrWESP, NULL);
+            IDSetNumber(&EqPECNV, NULL);
 
             return true;
 
@@ -629,6 +601,44 @@ bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
     return INDI::Telescope::ISNewSwitch(dev,name,states,names,n);
 }
 
+bool ScopeSim::Abort()
+{
+    if (MovementNSSP.s == IPS_BUSY)
+    {
+        IUResetSwitch(&MovementNSSP);
+        MovementNSSP.s = IPS_IDLE;
+        IDSetSwitch(&MovementNSSP, NULL);
+    }
+
+    if (MovementWESP.s == IPS_BUSY)
+    {
+        MovementWESP.s = IPS_IDLE;
+        IUResetSwitch(&MovementWESP);
+        IDSetSwitch(&MovementWESP, NULL);
+    }
+
+    if (ParkSV.s == IPS_BUSY)
+    {
+        ParkSV.s       = IPS_IDLE;
+        IUResetSwitch(&ParkSV);
+        IDSetSwitch(&ParkSV, NULL);
+    }
+
+    if (EqNV.s == IPS_BUSY)
+    {
+        EqNV.s = IPS_IDLE;
+        IDSetNumber(&EqNV, NULL);
+    }
+
+
+    TrackState = SCOPE_IDLE;
+
+    AbortSV.s      = IPS_OK;
+    IUResetSwitch(&AbortSV);
+    IDSetSwitch(&AbortSV, "Telescope aborted.");
+
+    return true;
+}
 
 
 bool ScopeSim::MoveNS(TelescopeMotionNS dir)
@@ -642,9 +652,9 @@ bool ScopeSim::MoveNS(TelescopeMotionNS dir)
             last_motion = MOTION_NORTH;
         else
         {
-            IUResetSwitch(MovementNSSP);
-            MovementNSSP->s = IPS_IDLE;
-            IDSetSwitch(MovementNSSP, NULL);
+            IUResetSwitch(&MovementNSSP);
+            MovementNSSP.s = IPS_IDLE;
+            IDSetSwitch(&MovementNSSP, NULL);
         }
         break;
 
@@ -653,9 +663,9 @@ bool ScopeSim::MoveNS(TelescopeMotionNS dir)
           last_motion = MOTION_SOUTH;
       else
       {
-          IUResetSwitch(MovementNSSP);
-          MovementNSSP->s = IPS_IDLE;
-          IDSetSwitch(MovementNSSP, NULL);
+          IUResetSwitch(&MovementNSSP);
+          MovementNSSP.s = IPS_IDLE;
+          IDSetSwitch(&MovementNSSP, NULL);
       }
       break;
     }
@@ -674,9 +684,9 @@ bool ScopeSim::MoveWE(TelescopeMotionWE dir)
             last_motion = MOTION_WEST;
         else
         {
-            IUResetSwitch(MovementWESP);
-            MovementWESP->s = IPS_IDLE;
-            IDSetSwitch(MovementWESP, NULL);
+            IUResetSwitch(&MovementWESP);
+            MovementWESP.s = IPS_IDLE;
+            IDSetSwitch(&MovementWESP, NULL);
         }
         break;
 
@@ -685,9 +695,9 @@ bool ScopeSim::MoveWE(TelescopeMotionWE dir)
           last_motion = MOTION_EAST;
       else
       {
-          IUResetSwitch(MovementWESP);
-          MovementWESP->s = IPS_IDLE;
-          IDSetSwitch(MovementWESP, NULL);
+          IUResetSwitch(&MovementWESP);
+          MovementWESP.s = IPS_IDLE;
+          IDSetSwitch(&MovementWESP, NULL);
       }
       break;
     }
@@ -696,3 +706,44 @@ bool ScopeSim::MoveWE(TelescopeMotionWE dir)
 
 }
 
+bool ScopeSim::GuideNorth(float ms)
+{
+    guiderNSTarget[GUIDE_NORTH] = ms;
+    guiderNSTarget[GUIDE_SOUTH] = 0;
+    return true;
+}
+
+bool ScopeSim::GuideSouth(float ms)
+{
+    guiderNSTarget[GUIDE_SOUTH] = ms;
+    guiderNSTarget[GUIDE_NORTH] = 0;
+    return true;
+
+}
+
+bool ScopeSim::GuideEast(float ms)
+{
+
+    guiderEWTarget[GUIDE_EAST] = ms;
+    guiderEWTarget[GUIDE_WEST] = 0;
+    return true;
+
+}
+
+bool ScopeSim::GuideWest(float ms)
+{
+    guiderEWTarget[GUIDE_WEST] = ms;
+    guiderEWTarget[GUIDE_EAST] = 0;
+    return true;
+
+}
+
+bool ScopeSim::canSync()
+{
+    return true;
+}
+
+bool ScopeSim::canPark()
+{
+    return true;
+}
