@@ -25,21 +25,22 @@
 
 /** \file indidevapi.h
     \brief Interface to the reference INDI C API device implementation on the Device Driver side.
-    \author Elwood C. Downey
-    \author Jasem Mutlaq
+*
+\author Elwood C. Downey
+\author Jasem Mutlaq
      
-     This file is divided into two main sections:\n
-     <ol><li> Functions the INDI device driver framework defines which the Driver may
-     call:</li>
+This file is divided into two main sections:\n
+<ol><li> Functions the INDI device driver framework defines which the Driver may
+call:</li>
  
-      <ul><li>IDxxx functions to send messages to an INDI client.</li>
-      <li>IExxx functions to implement the event driven model.</li>
-      <li>IUxxx functions to perform handy utility functions.</li></ul>
+<ul><li>IDxxx functions to send messages to an INDI client.</li>
+<li>IExxx functions to implement the event driven model.</li>
+<li>IUxxx functions to perform handy utility functions.</li></ul>
  
-     <li>Functions the INDI device driver framework calls which the Driver must
-    define:</li>
+<li>Functions the INDI device driver framework calls which the Driver must
+define:</li>
  
-     <ul><li>ISxxx to respond to messages from a Client.</li></ul></ol>
+<ul><li>ISxxx to respond to messages from a Client.</li></ul></ol>
 
 <p>These functions are the interface to the INDI C-language Device Driver
 reference implementation library. Any driver that uses this interface is
@@ -449,6 +450,16 @@ extern IBLOB *IUFindBLOB(const IBLOBVectorProperty *bvp, const char *name);
 */
 extern ISwitch *IUFindOnSwitch (const ISwitchVectorProperty *sp);
 
+/** \brief Returns the index of first ON switch it finds in the vector switch property.
+
+*   \note This is only valid for ISR_1OFMANY mode. That is, when only one switch out of many is allowed to be ON. Do not use this function if you can have multiple ON switches in the same vector property.
+*
+* \param sp a pointer to a switch vector property.
+* \return index to the \e first ON ISwitch member if found. If all switches are off, -1 is returned.
+*/
+
+extern int IUFindOnSwitchIndex (const ISwitchVectorProperty *sp);
+
 /** \brief Reset all switches in a switch vector property to OFF.
 *
 * \param svp a pointer to a switch vector property.
@@ -485,6 +496,29 @@ extern int IUUpdateNumber(INumberVectorProperty *nvp, double values[], char *nam
 */
 extern int IUUpdateText(ITextVectorProperty *tvp, char * texts[], char *names[], int n);
 
+/** \brief Update all BLOB members in a BLOB vector property.
+*
+* \param bvp a pointer to a BLOB vector property.
+* \param sizes sizes of the blobs.
+* \param blobsizes size of the blobs, raw without compression.
+* \param blobs a pointer to the BLOB members
+* \param names the names of the IBLOB members to update.
+* \param formats The blob format or extension.
+* \param n the number of IBLOB members to update.
+* \return 0 if update successful, -1 otherwise. Update will fail in case of property name mismatch.
+*/
+extern int IUUpdateBLOB(IBLOBVectorProperty *bvp, int sizes[], int blobsizes[], char *blobs[], char *formats[], char *names[], int n);
+
+/** \brief Function to save blob metadata in the corresponding blob.
+    \param bp pointer to an IBLOB member.
+    \param size size of the blob buffer encoded in base64
+    \param blobsize actual size of the buffer after base64 decoding. This is the actual byte count used in drivers.
+    \param blob pointer to the blob buffer
+    \param format format of the blob buffer
+    \note Do not call this function directly, it is called internally by IUUpdateBLOB.
+    */
+extern int IUSaveBLOB(IBLOB *bp, int size, int blobsize, char *blob, char *format);
+
 /** \brief Function to update the min and max elements of a number in the client
     \param nvp pointer to an INumberVectorProperty.
  */
