@@ -271,6 +271,45 @@ int IUUpdateText(ITextVectorProperty *tvp, char * texts[], char *names[], int n)
 
 }
 
+
+/* Update property BLOB in accord with BLOBs and names */
+int IUUpdateBLOB(IBLOBVectorProperty *bvp, int sizes[], int blobsizes[], char *blobs[], char *formats[], char *names[], int n)
+{
+  int i=0;
+
+  IBLOB *bp;
+
+  for (i = 0; i < n; i++)
+  {
+    bp = IUFindBLOB(bvp, names[i]);
+    if (!bp)
+    {
+        bvp->s = IPS_IDLE;
+    IDSetBLOB(bvp, "Error: %s is not a member of %s property.", names[i], bvp->name);
+    return -1;
+    }
+  }
+
+  /* First loop checks for error, second loop set all values atomically*/
+  for (i=0; i < n; i++)
+  {
+    bp = IUFindBLOB(bvp, names[i]);
+    IUSaveBLOB(bp, sizes[i], blobsizes[i], blobs[i], formats[i]);
+  }
+
+  return 0;
+
+}
+
+int IUSaveBLOB(IBLOB *bp, int size, int blobsize, char *blob, char *format)
+{
+    bp->bloblen = blobsize;
+    bp->size    = size;
+    bp->blob    = blob;
+    strncpy(bp->format, format, MAXINDIFORMAT);
+    return 0;
+}
+
 void IUFillSwitch(ISwitch *sp, const char *name, const char * label, ISState s)
 {
   strncpy(sp->name, name, MAXINDINAME);
@@ -439,7 +478,7 @@ IUSnoopNumber (XMLEle *root, INumberVectorProperty *nvp)
 	/* match each INumber with a oneNumber */
 	for (i = 0; i < nvp->nnp; i++) {
 	    for (ep = nextXMLEle(root,1); ep; ep = nextXMLEle(root,0)) {
-		if (!strcmp (tagXMLEle(ep), "oneNumber") &&
+        if (!strcmp (tagXMLEle(ep)+3, "Number") &&
 			!strcmp (nvp->np[i].name, findXMLAttValu(ep, "name"))) {
 		    if (f_scansexa (pcdataXMLEle(ep), &nvp->np[i].value) < 0)
 			return (-1);	/* bad number format */
@@ -477,7 +516,7 @@ IUSnoopText (XMLEle *root, ITextVectorProperty *tvp)
 	/* match each IText with a oneText */
 	for (i = 0; i < tvp->ntp; i++) {
 	    for (ep = nextXMLEle(root,1); ep; ep = nextXMLEle(root,0)) {
-		if (!strcmp (tagXMLEle(ep), "oneText") &&
+        if (!strcmp (tagXMLEle(ep)+3, "Text") &&
 			!strcmp (tvp->tp[i].name, findXMLAttValu(ep, "name"))) {
 		    IUSaveText (&tvp->tp[i], pcdataXMLEle(ep));
 		    break;
@@ -514,7 +553,7 @@ IUSnoopLight (XMLEle *root, ILightVectorProperty *lvp)
 
 	/* match each oneLight with one ILight */
 	for (ep = nextXMLEle(root,1); ep; ep = nextXMLEle(root,0)) {
-	    if (!strcmp (tagXMLEle(ep), "oneLight")) {
+        if (!strcmp (tagXMLEle(ep)+3, "Light")) {
 		const char *name = findXMLAttValu (ep, "name");
 		for (i = 0; i < lvp->nlp; i++) {
 		    if (!strcmp (lvp->lp[i].name, name)) {
@@ -553,7 +592,7 @@ IUSnoopSwitch (XMLEle *root, ISwitchVectorProperty *svp)
 
 	/* match each oneSwitch with one ISwitch */
 	for (ep = nextXMLEle(root,1); ep; ep = nextXMLEle(root,0)) {
-	    if (!strcmp (tagXMLEle(ep), "oneSwitch")) {
+        if (!strcmp (tagXMLEle(ep)+3, "Switch")) {
 		const char *name = findXMLAttValu (ep, "name");
 		for (i = 0; i < svp->nsp; i++) {
 		    if (!strcmp (svp->sp[i].name, name)) {
@@ -593,7 +632,7 @@ IUSnoopBLOB (XMLEle *root, IBLOBVectorProperty *bvp)
 
 	/* match each oneBLOB with one IBLOB */
 	for (ep = nextXMLEle(root,1); ep; ep = nextXMLEle(root,0)) {
-	    if (!strcmp (tagXMLEle(ep), "oneBLOB")) {
+        if (!strcmp (tagXMLEle(ep)+3, "BLOB")) {
 		const char *name = findXMLAttValu (ep, "name");
 		for (i = 0; i < bvp->nbp; i++) {
 		    IBLOB *bp = &bvp->bp[i];
