@@ -64,6 +64,7 @@
 
 #define INDIPORT        7624            /* default TCP/IP port to listen */
 #define	REMOTEDVR	(-1234)		/* invalid PID to flag remote drivers */
+#define MAXSBUF     512
 #define	MAXRBUF		4096		/* max read buffering here */
 #define	MAXWSIZ		4096		/* max bytes/write */
 #define	DEFMAXQSIZ	10		/* default max q behind, MB */
@@ -98,7 +99,7 @@ struct
 {
     const char *name;                      /* Path to FIFO for dynamic startups & shutdowns of drivers */
     int fd;
-    FILE *fs;
+    //FILE *fs;
 } fifo;
 
 /* info for each connected client */
@@ -602,18 +603,21 @@ indiListen ()
 /* Attempt to open up FIFO */
 static void indiFIFO(void)
 {
+    close(fifo.fd);
+    fifo.fd=-1;
+
     /* Open up FIFO, if available */
     if (fifo.name)
     {
-        fifo.fd = open(fifo.name, O_RDONLY);
-                  if (fifo.fd < 0)
-                  {
-                       fprintf(stderr, "%s: open(%s): %s.\n", indi_tstamp(NULL), fifo.name, strerror(errno));
-                        Bye();
-                   }
+        fifo.fd = open(fifo.name, O_RDWR | O_NONBLOCK);
 
-        fifo.fs = fdopen(fifo.fd, "r");
+       if (fifo.fd < 0)
+       {
+           fprintf(stderr, "%s: open(%s): %s.\n", indi_tstamp(NULL), fifo.name, strerror(errno));
+           Bye();
+       }
     }
+
 }
 
 /* service traffic from clients and drivers */
@@ -628,7 +632,7 @@ indiRun(void)
 	FD_ZERO(&ws);
 	FD_ZERO(&rs);
 
-        if (fifo.name && fifo.fd > 0)
+        if (fifo.name && fifo.fd >=0)
         {
            FD_SET(fifo.fd, &rs);
            maxfd = fifo.fd;
@@ -685,7 +689,8 @@ indiRun(void)
 
 
         /* new command from FIFO? */
-        if (s > 0 && FD_ISSET(fifo.fd, &rs)) {
+        if (s > 0 && fifo.fd >= 0 && FD_ISSET(fifo.fd, &rs))
+        {
             newFIFO();
             s--;
         }
@@ -737,175 +742,136 @@ indiRun(void)
 /* Read commands from FIFO and process them. Start/stop drivers accordingly */
 static void newFIFO(void)
 {
-    char line[MAXRBUF], tDriver[MAXRBUF], tConfig[MAXRBUF], tDev[MAXRBUF];
-    static char *envDev=NULL, *envConfig=NULL;
-    const char *delm = " ";
-    char *token, *cp, *tp;
+    //char line[MAXRBUF], tDriver[MAXRBUF], tConfig[MAXRBUF], tDev[MAXRBUF], tSkel[MAXRBUF], envDev[MAXRBUF], envConfig[MAXRBUF], envSkel[MAXR];
+    char line[MAXRBUF];
     DvrInfo *dp = NULL;
-    int startCmd=0;
+    int startCmd=0, i=0;
 
-    if (envDev == NULL)
-        envDev = (char *) malloc(MAXRBUF* sizeof(char));
-    if (envConfig == NULL)
-        envConfig = (char *) malloc(MAXRBUF * sizeof(char));
-
-    while ( fgets (line, MAXRBUF, fifo.fs) != NULL)
+    while (i < MAXRBUF)
     {
-        if (verbose)
+        if (read(fifo.fd, line+i, 1) <= 0)
+        {
+            // Reset FIFO now, otherwise select will always return with no data from FIFO.
+            indiFIFO();
+            return;
+        }
+
+        if (line[i] == '\n')
+        {
+            line[i] = '\0';
+            i=0;
+        }
+        else
+        {
+          i++;
+          continue;
+        }
+
+     if (verbose)
             fprintf(stderr, "FIFO: %s\n", line);
 
-        tDev[0] = '\0', tDriver[0] = '\0', tConfig[0] = '\0', envDev[0] = '\0', envConfig[0] = '\0';
-        cp = strdup(line);
+     char cmd[MAXSBUF], arg[3][1], var[3][MAXSBUF], tDriver[MAXSBUF], tName[MAXSBUF], envDev[MAXSBUF], envConfig[MAXSBUF], envSkel[MAXSBUF];
 
-        token = strsep(&cp, delm);
+     memset(&tDriver[0], 0, sizeof(MAXSBUF));
+     memset(&tName[0], 0, sizeof(MAXSBUF));
+     memset(&envDev[0], 0, sizeof(MAXSBUF));
+     memset(&envConfig[0], 0, sizeof(MAXSBUF));
+     memset(&envSkel[0], 0, sizeof(MAXSBUF));
 
-        if (!strcmp(token, "start") || !strcmp(token, "stop"))
-        {
-            //fprintf(stderr, "TOKEN: %s\n", token);
+     int n = sscanf(line, "%s %s -%1c \"%512[^\"]\" -%1c \"%512[^\"]\" -%1c \"%512[^\"]\"", cmd, tDriver, arg[0], var[0], arg[1], var[1]
+                    , arg[2], var[2]);
 
-                if (!strcmp(token, "start"))
-                    startCmd = 1;
 
-                token = strsep(&cp, delm);
+     int n_args = (n - 2)/2;
 
-                if (!token)
-                    continue;
+     int j=0;
+     for (j=0; j < n_args; j++)
+     {
+         //fprintf(stderr, "arg[%d]: %c\n", i, arg[j][0]);
+         //fprintf(stderr, "var[%d]: %s\n", i, var[j]);
 
-               strncpy(tDriver, token, MAXRBUF);
-               if (tp = strchr(tDriver, '\n'))
-                   *tp = '\0';
+         if (arg[j][0] == 'n')
+         {
+             strncpy(tName, var[j], MAXSBUF-1);
+             tName[MAXSBUF-1] = '\0';
+             snprintf(envDev, MAXSBUF, "INDIDEV=%s", tName);
+             if (verbose)
+                fprintf(stderr, "With name: %s\n", envDev);
 
-               if (verbose)
-                fprintf(stderr, "FIFO: Request for %s driver: %s\n", (startCmd == 1) ? "starting" : "stopping", tDriver);
-
-               /* Find more name + config */
-               token = strsep(&cp, delm);
-
-               if (token)
-               {
-                 /* If config file detected, copy it */
-                if (strstr(token, ".xml"))                 
-                    strncpy(tConfig, token, MAXRBUF);
-                /* Get rid of quotes */
-                else if (strstr(token, "\"") || strstr(token, "'"))
-                {
-		    strncat(tDev, ++token, sizeof(tDev)-strlen(tDev)-1);
-                    while (token = strsep(&cp, delm) )
-                   {
-                     strcat(tDev, " ");
-                     strncat(tDev, token, sizeof(tDev)-strlen(tDev)-1);
-                     if ( (tp=strchr(tDev, '\"')) || (tp=strchr(tDev, '\'')))
-                     {
-                         //tDev[strlen(tDev)-1] = '\0';
-                         *tp='\0';
-                         break;
-                     }
-                    }
-                 }
-                 else
-                {
-                     strncpy(tDev, token, MAXRBUF);
-                     if (tp = strchr(tDev, '\n'))
-                         *tp = '\0';
-                 }
-
-                  /* Find config, if there is any */
-                  token = strsep(&cp, delm);
-                  if (token)
-                  {
-                      /* Get rid of quotes */
-                      if (strstr(token, "\"") || strstr(token, "'"))
-                      {
-                       strncat(tConfig, ++token, sizeof(tConfig)-strlen(tDev)-1);
-                       while (token = strsep(&cp, delm) )
-                       {
-                          strcat(tConfig, " ");
-                          strncat(tConfig, token, sizeof(tConfig)-strlen(tDev)-1);
-
-                          if ( (tp=strchr(tConfig, '\"')) || (tp=strchr(tConfig, '\'')))
-                          {
-                                 //tConfig[strlen(tConfig)-1] = '\0';
-                              *tp = '\0';
-                              break;
-                          }
-                       }
-                      }
-                       else
-                      {
-                           strncpy(tConfig, token, MAXRBUF);
-                           if (tp = strchr(tConfig, '\n'))
-                               *tp = '\0';
-                       }
-                  }
-              }
-
-               /* Did we find device name? */
-               if (tDev[0])
-               {
-                 snprintf(envDev, MAXRBUF, "INDIDEV=%s", tDev);
-
-                 if (verbose)
-                    fprintf(stderr, "With name: %s\n", envDev);
-
-                 putenv(envDev);
-
-                 //fprintf(stderr, "envionment check INDIDEV: %s\n", getenv("INDIDEV"));
-               }
-
-               /* Did we find config file */
-               if (tConfig[0])
-               {
-                   snprintf(envConfig, MAXRBUF, "INDICONFIG=%s", tConfig);
-
-                   if (verbose)
-                    fprintf(stderr, "With config: %s\n", envConfig);
-
-                   putenv(envConfig);
-               }
-
-               if (startCmd)
-               {
-                   if (verbose)
-                        fprintf(stderr, "FIFO: Starting driver %s\n", tDriver);
-                    dp = allocDvr();
-                    strncpy(dp->name, tDriver, MAXINDIDEVICE);
-                    strncpy(dp->dev, tDev, MAXINDIDEVICE);
-                    startDvr (dp);
-              }
-               else
-               {
-                  for (dp = dvrinfo; dp < &dvrinfo[ndvrinfo]; dp++)
-                   {
-                       if (!strcmp(dp->name, tDriver) && dp->active==1)
-                       {
-                           /* If device name is given, check against it before shutting down */
-                           if (tDev[0] && strcmp(dp->dev, tDev))
-                               continue;
-
-                           if (verbose)
-                               fprintf(stderr, "FIFO: Shutting down driver: %s\n", tDriver);
-
-                           shutdownDvr(dp, 0);
-
-                               /* Inform clients that this driver is dead */
-                               XMLEle *root = addXMLEle (NULL, "delProperty");
-                               addXMLAtt(root, "device", dp->dev);
-                               Msg * mp = newMsg();
-
-                               q2Clients(NULL, 0, dp->dev, NULL, mp, root);
-                               if (mp->count > 0)
-                                   setMsgXMLEle (mp, root);
-                               else
-                                   freeMsg (mp);
-                               delXMLEle (root);
-
-                           break;
-
-                       }
-                   }
-               }
+             putenv(envDev);
          }
+         else if (arg[j][0] == 'c')
+         {
+             snprintf(envConfig, MAXSBUF, "INDICONFIG=%s", var[j]);
+
+             if (verbose)
+              fprintf(stderr, "With config: %s\n", envConfig);
+
+             putenv(envConfig);
+
+         }
+         else if (arg[j][0] == 's')
+         {
+             snprintf(envSkel, MAXSBUF, "INDISKEL=%s", var[j]);
+
+             if (verbose)
+              fprintf(stderr, "With skeketon: %s\n", envSkel);
+
+             putenv(envSkel);
+
+         }
+
+     }
+
+     if (!strcmp(cmd, "start"))
+         startCmd = 1;
+     else
+         startCmd = 0;
+
+    if (startCmd)
+    {
+          if (verbose)
+             fprintf(stderr, "FIFO: Starting driver %s\n", tDriver);
+          dp = allocDvr();
+          strncpy(dp->name, tDriver, MAXINDIDEVICE);
+          //strncpy(dp->dev, tName, MAXINDIDEVICE);
+          startDvr (dp);
     }
+    else
+    {
+     for (dp = dvrinfo; dp < &dvrinfo[ndvrinfo]; dp++)
+     {
+         fprintf(stderr, "dp->name: %s - tDriver: %s\n", dp->name, tDriver);
+         if (!strcmp(dp->name, tDriver) && dp->active==1)
+         {
+             fprintf(stderr, "name: %s - dp->dev: %s\n", tName, dp->dev);
+
+            /* If device name is given, check against it before shutting down */
+            if (tName[0] && strcmp(dp->dev, tName))
+                  continue;
+           if (verbose)
+               fprintf(stderr, "FIFO: Shutting down driver: %s\n", tDriver);
+
+            shutdownDvr(dp, 0);
+
+           /* Inform clients that this driver is dead */
+           XMLEle *root = addXMLEle (NULL, "delProperty");
+           addXMLAtt(root, "device", dp->dev);
+
+           prXMLEle(stderr, root, 0);
+           Msg * mp = newMsg();
+
+          q2Clients(NULL, 0, dp->dev, NULL, mp, root);
+          if (mp->count > 0)
+              setMsgXMLEle (mp, root);
+          else
+              freeMsg (mp);
+         delXMLEle (root);
+         break;
+         }
+     }
+    }
+   }
 }
 
 /* prepare for new client arriving on lsocket.
@@ -1272,8 +1238,8 @@ q2RDrivers (const char *dev, Msg *mp, XMLEle *root)
 	    int isremote = (dp->pid == REMOTEDVR);
             if (dp->active == 0)
                 continue;
-	    if (dev[0] && dp->dev[0] && strcmp (dev, dp->dev))
-		continue;	/* driver known to not support this dev */
+        if (dev[0] && dp->dev[0] && strcmp (dev, dp->dev))
+                continue;	/* driver known to not support this dev */
 	    if (!dev[0] && isremote && sawremote)
 		continue;	/* already sent generic to another remote */
 	    if (isremote)
@@ -1646,7 +1612,7 @@ addClDevice (ClInfo *cp, const char *dev, const char *name, int isblob)
             for (i = 0; i < cp->nprops; i++)
             {
                 Property *pp = &cp->props[i];
-                if (!strcmp (pp->dev, dev) && (!pp->name[0] || !strcmp(pp->name, name)))
+                if (!strcmp (pp->dev, dev) && (name==NULL || !strcmp(pp->name, name)))
                     return;
             }
         }
