@@ -24,14 +24,15 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
+#include <fcntl.h>
 
 #include "baseclient.h"
-#include "basedriver.h"
+#include "basedevice.h"
 #include "indicom.h"
 
 #include <errno.h>
 
-#define MAXINDIBUF 64
+#define MAXINDIBUF 256
 
 INDI::BaseClient::BaseClient()
 {
@@ -45,9 +46,11 @@ INDI::BaseClient::BaseClient()
 
 INDI::BaseClient::~BaseClient()
 {
-    close(sockfd);
+   // close(m_sendFd);
+   // close(m_receiveFd);
 }
 
+
 void INDI::BaseClient::setServer(const char * hostname, unsigned int port)
 {
     cServer = hostname;
@@ -64,6 +67,8 @@ bool INDI::BaseClient::connectServer()
 {
     struct sockaddr_in serv_addr;
     struct hostent *hp;
+    int pipefd[2];
+    int ret = 0;
 
     /* lookup host address */
     hp = gethostbyname(cServer.c_str());
@@ -94,6 +99,23 @@ bool INDI::BaseClient::connectServer()
     /* prepare for line-oriented i/o with client */
     svrwfp = fdopen (sockfd, "w");
 
+    if (svrwfp == NULL)
+    {
+        perror("fdopen");
+        return false;
+    }
+
+    ret = socketpair(PF_UNIX,SOCK_STREAM,0,pipefd);
+
+    if (ret < 0)
+    {
+        IDLog("notify pipe: %s\n", strerror(errno));
+        return false;
+    }
+
+    m_receiveFd = pipefd[0];
+    m_sendFd = pipefd[1];
+
     int result = pthread_create( &listen_thread, NULL, &INDI::BaseClient::listenHelper, this);
 
     if (result != 0)
@@ -102,34 +124,47 @@ bool INDI::BaseClient::connectServer()
         return false;
     }
 
-    serverConnected();
     sConnected = true;
+    serverConnected();
 
     return true;
 }
 
 bool INDI::BaseClient::disconnectServer()
 {
+    //IDLog("Server disconnected called\n");
     if (sConnected == false)
         return true;
 
+    sConnected = false;
+
+    shutdown(sockfd, SHUT_RDWR);
+    write(m_sendFd,"1",1);
+
+
     if (svrwfp != NULL)
         fclose(svrwfp);
    svrwfp = NULL;
 
-   close(sockfd);
+   pthread_join(listen_thread, NULL);
 
-    serverDisconnected();
+   return true;
+}
 
-    sConnected = false;
+void INDI::BaseClient::connectDevice(const char *deviceName)
+{
+    setDriverConnection(true, deviceName);
+}
 
-    return true;
+void INDI::BaseClient::disconnectDevice(const char *deviceName)
+{
+        setDriverConnection(false, deviceName);
 }
 
 
 void INDI::BaseClient::setDriverConnection(bool status, const char *deviceName)
 {
-    INDI::BaseDriver *drv = getDriver(deviceName);
+    INDI::BaseDevice *drv = getDevice(deviceName);
     ISwitchVectorProperty *drv_connection = NULL;
 
     if (drv == NULL)
@@ -155,7 +190,7 @@ void INDI::BaseClient::setDriverConnection(bool status, const char *deviceName)
         drv_connection->sp[0].s = ISS_ON;
         drv_connection->sp[1].s = ISS_OFF;
 
-        sendNewSwitch(drv_connection, &(drv_connection->sp[0]));
+        sendNewSwitch(drv_connection);
     }
     else
     {
@@ -168,17 +203,17 @@ void INDI::BaseClient::setDriverConnection(bool status, const char *deviceName)
         drv_connection->sp[0].s = ISS_OFF;
         drv_connection->sp[1].s = ISS_ON;
 
-        sendNewSwitch(drv_connection, &(drv_connection->sp[1]));
+        sendNewSwitch(drv_connection);
 
     }
 }
 
 
-INDI::BaseDriver * INDI::BaseClient::getDriver(const char * deviceName)
+INDI::BaseDevice * INDI::BaseClient::getDevice(const char * deviceName)
 {
-    vector<INDI::BaseDriver *>::const_iterator devi;
+    vector<INDI::BaseDevice *>::const_iterator devi;
     for ( devi = cDevices.begin(); devi != cDevices.end(); devi++)
-        if (!strcmp(deviceName, (*devi)->deviceName()))
+        if (!strcmp(deviceName, (*devi)->getDeviceName()))
             return (*devi);
 
     return NULL;
@@ -192,9 +227,12 @@ void * INDI::BaseClient::listenHelper(void *context)
 
 void INDI::BaseClient::listenINDI()
 {
-    char msg[MAXRBUF];
     char buffer[MAXINDIBUF];
+    char msg[MAXRBUF];
+
     int n=0, err_code=0;
+    int maxfd=0;
+    fd_set rs;
 
     if (cDeviceNames.empty())
        fprintf(svrwfp, "<getProperties version='%g'/>\n", INDIV);
@@ -207,46 +245,93 @@ void INDI::BaseClient::listenINDI()
 
     fflush (svrwfp);
 
+    FD_ZERO(&rs);
+
+    FD_SET(sockfd, &rs);
+    if (sockfd > maxfd)
+        maxfd = sockfd;
+
+    FD_SET(m_receiveFd, &rs);
+    if (m_receiveFd > maxfd)
+        maxfd = m_receiveFd;
+
+
     lillp = newLilXML();
 
     /* read from server, exit if find all requested properties */
     while (sConnected)
     {
-        n = read(sockfd, buffer, MAXINDIBUF);
 
-        if (n ==0)
+        n = select (maxfd+1, &rs, NULL, NULL, NULL);
+
+        if (n < 0)
         {
-            perror ("read");
-            fprintf (stderr,"INDI server %s/%d disconnected\n", cServer.c_str(), cPort);
-            serverDisconnected();
-            return;
+            fprintf (stderr,"INDI server %s/%d disconnected.\n", cServer.c_str(), cPort);
+            close(sockfd);
+            break;
         }
 
-        for (int i=0; i < n; i++)
+        // Received terminiation string from main thread
+        if (n > 0 && FD_ISSET(m_receiveFd, &rs))
         {
-            XMLEle *root = readXMLEle (lillp, buffer[i], msg);
-            if (root)
+            sConnected = false;
+            break;
+        }
+
+
+        if (n > 0 && FD_ISSET(sockfd, &rs))
+        {
+            n = recv(sockfd, buffer, MAXINDIBUF, MSG_DONTWAIT);
+            if (n<=0)
             {
-                if ( (err_code = dispatchCommand(root, msg)) < 0)
+
+                if (n==0)
                 {
-                     // Silenty ignore property duplication errors
-                     if (err_code != INDI_PROPERTY_DUPLICATED)
-                     {
-                         IDLog("Dispatch command error: %s\n", msg);
-                         prXMLEle (stderr, root, 0);
-                     }
+                    fprintf (stderr,"INDI server %s/%d disconnected.\n", cServer.c_str(), cPort);
+                    close(sockfd);
+                    break;
                 }
-
-               delXMLEle (root);	/* not yet, delete and continue */
+                else
+                    continue;
             }
-            else if (msg[0])
+
+            for (int i=0; i < n; i++)
             {
-               fprintf (stderr, "Bad XML from %s/%d: %s\n%s\n", cServer.c_str(), cPort, msg, buffer);
-               return;
+              // IDLog("Getting #%d bytes in for loop, calling readXMLEle for byte %d\n", n, i);
+                XMLEle *root = readXMLEle (lillp, buffer[i], msg);
+                //IDLog("############# BLOCK # POST READ XML ELE #####################\n");
+
+                if (root)
+                {
+                    if ( (err_code = dispatchCommand(root, msg)) < 0)
+                    {
+                         // Silenty ignore property duplication errors
+                         if (err_code != INDI_PROPERTY_DUPLICATED)
+                         {
+                             IDLog("Dispatch command error(%d): %s\n", err_code, msg);
+                             prXMLEle (stderr, root, 0);
+                         }
+                    }
+
+                   delXMLEle (root);	// not yet, delete and continue
+                }
+                else if (msg[0])
+                {
+                   fprintf (stderr, "Bad XML from %s/%d: %s\n%s\n", cServer.c_str(), cPort, msg, buffer);
+                   return;
+                }
             }
         }
+
     }
 
+    delLilXML(lillp);
+
+    serverDisconnected( (sConnected == false) ? 0 : -1);
+    sConnected = false;
+
+    pthread_exit(0);
+
 }
 
 int INDI::BaseClient::dispatchCommand(XMLEle *root, char * errmsg)
@@ -257,13 +342,19 @@ int INDI::BaseClient::dispatchCommand(XMLEle *root, char * errmsg)
         return delPropertyCmd(root, errmsg);
 
     /* Get the device, if not available, create it */
-    INDI::BaseDriver *dp = findDev (root, 1, errmsg);
+    INDI::BaseDevice *dp = findDev (root, 1, errmsg);
     if (dp == NULL)
     {
         strcpy(errmsg,"No device available and none was created");
         return INDI_DEVICE_NOT_FOUND;
     }
 
+    // FIXME REMOVE THIS
+
+    // Ignore echoed newXXX
+    if (strstr(tagXMLEle(root), "new"))
+        return 0;
+
     if ((!strcmp (tagXMLEle(root), "defTextVector"))  ||
        (!strcmp (tagXMLEle(root), "defNumberVector")) ||
        (!strcmp (tagXMLEle(root), "defSwitchVector")) ||
@@ -288,32 +379,39 @@ int INDI::BaseClient::dispatchCommand(XMLEle *root, char * errmsg)
 int INDI::BaseClient::delPropertyCmd (XMLEle *root, char * errmsg)
 {
     XMLAtt *ap;
-    INDI::BaseDriver *dp;
+    INDI::BaseDevice *dp;
 
     /* dig out device and optional property name */
     dp = findDev (root, 0, errmsg);
     if (!dp)
         return INDI_DEVICE_NOT_FOUND;
 
-    checkMsg(root, dp);
+    dp->checkMessage(root);
 
     ap = findXMLAtt (root, "name");
 
     /* Delete property if it exists, otherwise, delete the whole device */
     if (ap)
-        return dp->removeProperty(valuXMLAtt(ap));
+    {
+        INDI::Property *rProp = dp->getProperty(valuXMLAtt(ap));
+        removeProperty(rProp);
+        int errCode = dp->removeProperty(valuXMLAtt(ap), errmsg);
+
+        return errCode;
+    }
     // delete the whole device
     else
-        return removeDevice(dp->deviceName(), errmsg);
+        return removeDevice(dp->getDeviceName(), errmsg);
 }
 
 int INDI::BaseClient::removeDevice( const char * devName, char * errmsg )
 {
-    std::vector<INDI::BaseDriver *>::iterator devicei;
+    std::vector<INDI::BaseDevice *>::iterator devicei;
 
     for (devicei =cDevices.begin(); devicei != cDevices.end();)
     {
-      if (strcmp(devName, (*devicei)->deviceName()))
+
+      if (!strcmp(devName, (*devicei)->getDeviceName()))
       {
           delete *devicei;
           devicei = cDevices.erase(devicei);
@@ -327,14 +425,14 @@ int INDI::BaseClient::removeDevice( const char * devName, char * errmsg )
     return INDI_DEVICE_NOT_FOUND;
 }
 
-INDI::BaseDriver * INDI::BaseClient::findDev( const char * devName, char * errmsg )
+INDI::BaseDevice * INDI::BaseClient::findDev( const char * devName, char * errmsg )
 {
 
-    std::vector<INDI::BaseDriver *>::const_iterator devicei;
+    std::vector<INDI::BaseDevice *>::const_iterator devicei;
 
     for (devicei = cDevices.begin(); devicei != cDevices.end(); devicei++)
     {
-        if (!strcmp(devName, (*devicei)->deviceName()))
+        if (!strcmp(devName, (*devicei)->getDeviceName()))
          return (*devicei);
 
     }
@@ -344,10 +442,10 @@ INDI::BaseDriver * INDI::BaseClient::findDev( const char * devName, char * errms
 }
 
 /* add new device */
-INDI::BaseDriver * INDI::BaseClient::addDevice (XMLEle *dep, char * errmsg)
+INDI::BaseDevice * INDI::BaseClient::addDevice (XMLEle *dep, char * errmsg)
 {
     //devicePtr dp(new INDI::BaseDriver());
-    INDI::BaseDriver *dp = new INDI::BaseDriver();
+    INDI::BaseDevice *dp = new INDI::BaseDevice();
     XMLAtt *ap;
     char * device_name;
 
@@ -366,16 +464,16 @@ INDI::BaseDriver * INDI::BaseClient::addDevice (XMLEle *dep, char * errmsg)
 
     cDevices.push_back(dp);
 
-    newDevice(device_name);
+    newDevice(dp);
 
     /* ok */
     return dp;
 }
 
-INDI::BaseDriver * INDI::BaseClient::findDev (XMLEle *root, int create, char * errmsg)
+INDI::BaseDevice * INDI::BaseClient::findDev (XMLEle *root, int create, char * errmsg)
 {
     XMLAtt *ap;
-    INDI::BaseDriver *dp;
+    INDI::BaseDevice *dp;
     char *dn;
 
     /* get device name */
@@ -406,54 +504,19 @@ INDI::BaseDriver * INDI::BaseClient::findDev (XMLEle *root, int create, char * e
  */
 int INDI::BaseClient::messageCmd (XMLEle *root, char * errmsg)
 {
-    checkMsg (root, findDev (root, 0, errmsg));
+    INDI::BaseDevice *dp =findDev (root, 0, errmsg);
+
+    if (dp)
+        dp->checkMessage(root);
+
     return (0);
 }
 
-/* add message to queue
- * N.B. don't put carriage control in msg, we take care of that.
- */
-void INDI::BaseClient::checkMsg (XMLEle *root, INDI::BaseDriver *dp)
-{
-    XMLAtt *ap;
-    ap = findXMLAtt(root, "message");
-
-    if (ap)
-        doMsg(root, dp);
-}
-
-/* Store msg in queue */
-void INDI::BaseClient::doMsg (XMLEle *msg, INDI::BaseDriver *dp)
-{
-    XMLAtt *message;
-    XMLAtt *time_stamp;
-    char msgBuffer[MAXRBUF];
-
-    if (dp == NULL)
-        return;
-
-    /* prefix our timestamp if not with msg */
-    time_stamp = findXMLAtt (msg, "timestamp");
-
-    if (time_stamp)
-        snprintf(msgBuffer, MAXRBUF, "%s ", valuXMLAtt(time_stamp));
-    else
-        snprintf(msgBuffer, MAXRBUF, "%s ", timestamp());
-
-    /* finally! the msg */
-    message = findXMLAtt(msg, "message");
-
-    if (!message) return;
-
-    // Prepend to the log
-   dp->addMessage(msgBuffer);
-   dp->addMessage(valuXMLAtt(message));
-   dp->addMessage("\n");
-\
-}
 
 void INDI::BaseClient::sendNewText (ITextVectorProperty *tvp)
 {
+    tvp->s = IPS_BUSY;
+
     fprintf(svrwfp, "<newTextVector\n");
     fprintf(svrwfp, "  device='%s'\n", tvp->device);
     fprintf(svrwfp, "  name='%s'\n>", tvp->name);
@@ -470,8 +533,33 @@ void INDI::BaseClient::sendNewText (ITextVectorProperty *tvp)
     fflush(svrwfp);
 }
 
+void INDI::BaseClient::sendNewText (const char * deviceName, const char * propertyName, const char* elementName, const char *text)
+{
+
+    INDI::BaseDevice *drv = getDevice(deviceName);
+
+    if (drv == NULL)
+        return;
+
+    ITextVectorProperty *tvp = drv->getText(propertyName);
+
+    if (tvp == NULL)
+        return;
+
+    IText * tp = IUFindText(tvp, elementName);
+
+    if (tp == NULL)
+        return;
+
+    IUSaveText(tp, text);
+
+    sendNewText(tvp);
+}
+
 void INDI::BaseClient::sendNewNumber (INumberVectorProperty *nvp)
 {
+    nvp->s = IPS_BUSY;
+
     fprintf(svrwfp, "<newNumberVector\n");
     fprintf(svrwfp, "  device='%s'\n", nvp->device);
     fprintf(svrwfp, "  name='%s'\n>", nvp->name);
@@ -488,22 +576,86 @@ void INDI::BaseClient::sendNewNumber (INumberVectorProperty *nvp)
    fflush(svrwfp);
 }
 
-void INDI::BaseClient::sendNewSwitch (ISwitchVectorProperty *svp, ISwitch *sp)
+void INDI::BaseClient::sendNewNumber (const char *deviceName, const char *propertyName, const char* elementName, double value)
 {
+    INDI::BaseDevice *drv = getDevice(deviceName);
+
+    if (drv == NULL)
+        return;
+
+    INumberVectorProperty *nvp = drv->getNumber(propertyName);
+
+    if (nvp == NULL)
+        return;
+
+    INumber * np = IUFindNumber(nvp, elementName);
+
+    if (np == NULL)
+        return;
+
+    np->value = value;
+
+    sendNewNumber(nvp);
+
+}
+
+void INDI::BaseClient::sendNewSwitch (ISwitchVectorProperty *svp)
+{
+    svp->s = IPS_BUSY;
+    ISwitch *onSwitch = IUFindOnSwitch(svp);
+
     fprintf(svrwfp, "<newSwitchVector\n");
 
     fprintf(svrwfp, "  device='%s'\n", svp->device);
     fprintf(svrwfp, "  name='%s'>\n", svp->name);
-    fprintf(svrwfp, "  <oneSwitch\n");
-    fprintf(svrwfp, "    name='%s'>\n", sp->name);
-    fprintf(svrwfp, "      %s\n", (sp->s == ISS_ON) ? "On" : "Off");
-    fprintf(svrwfp, "  </oneSwitch>\n");
+
+    if (svp->r == ISR_1OFMANY && onSwitch)
+    {
+        fprintf(svrwfp, "  <oneSwitch\n");
+        fprintf(svrwfp, "    name='%s'>\n", onSwitch->name);
+        fprintf(svrwfp, "      %s\n", (onSwitch->s == ISS_ON) ? "On" : "Off");
+        fprintf(svrwfp, "  </oneSwitch>\n");
+    }
+    else
+    {
+        for (int i=0; i < svp->nsp; i++)
+        {
+            fprintf(svrwfp, "  <oneSwitch\n");
+            fprintf(svrwfp, "    name='%s'>\n", svp->sp[i].name);
+            fprintf(svrwfp, "      %s\n", (svp->sp[i].s == ISS_ON) ? "On" : "Off");
+            fprintf(svrwfp, "  </oneSwitch>\n");
+
+        }
+    }
 
     fprintf(svrwfp, "</newSwitchVector>\n");
 
     fflush(svrwfp);
 }
 
+void INDI::BaseClient::sendNewSwitch (const char *deviceName, const char *propertyName, const char *elementName)
+{
+    INDI::BaseDevice *drv = getDevice(deviceName);
+
+    if (drv == NULL)
+        return;
+
+    ISwitchVectorProperty *svp = drv->getSwitch(propertyName);
+
+    if (svp == NULL)
+        return;
+
+    ISwitch * sp = IUFindSwitch(svp, elementName);
+
+    if (sp == NULL)
+        return;
+
+    sp->s = ISS_ON;
+
+    sendNewSwitch(svp);
+
+}
+
 void INDI::BaseClient::startBlob( const char *devName, const char *propName, const char *timestamp)
 {
     fprintf(svrwfp, "<newBLOBVector\n");
@@ -512,7 +664,7 @@ void INDI::BaseClient::startBlob( const char *devName, const char *propName, con
     fprintf(svrwfp, "  timestamp='%s'>\n",  timestamp);
 }
 
-void INDI::BaseClient::sendOneBlob( const char *blobName, unsigned int blobSize, const char *blobFormat, unsigned char * blobBuffer)
+void INDI::BaseClient::sendOneBlob( const char *blobName, unsigned int blobSize, const char *blobFormat, void * blobBuffer)
 {
     fprintf(svrwfp, "  <oneBLOB\n");
     fprintf(svrwfp, "    name='%s'\n", blobName);
@@ -520,7 +672,7 @@ void INDI::BaseClient::sendOneBlob( const char *blobName, unsigned int blobSize,
     fprintf(svrwfp, "    format='%s'>\n", blobFormat);
 
     for (unsigned i = 0; i < blobSize; i += 72)
-        fprintf(svrwfp, "    %.72s\n", blobBuffer+i);
+        fprintf(svrwfp, "    %.72s\n", ((char *) blobBuffer+i));
 
     fprintf(svrwfp, "   </oneBLOB>\n");
 }
