@@ -19,9 +19,12 @@
 #include "indiccd.h"
 
 #include <string.h>
-
+#include <time.h>
+#include <sys/time.h>
 #include <zlib.h>
 
+#include <fitsio.h>
+
 const char *IMAGE_SETTINGS_TAB = "Image Settings";
 const char *IMAGE_INFO_TAB     = "Image Info";
 const char *GUIDE_HEAD_TAB     = "Guide Head";
@@ -35,9 +38,12 @@ CCDChip::CCDChip()
     RawFrame=NULL;
     RawFrameSize=0;
 
+    BinX = BinY = 1;
+
     FrameType=LIGHT_FRAME;
 
     ImageFrameNP = new INumberVectorProperty;
+    AbortExposureSP = new ISwitchVectorProperty;
     FrameTypeSP = new ISwitchVectorProperty;
     ImageExposureNP = new INumberVectorProperty;
     ImageBinNP = new INumberVectorProperty;
@@ -54,6 +60,7 @@ CCDChip::~CCDChip()
     RawFrame=NULL;
 
     delete ImageFrameNP;
+    delete AbortExposureSP;
     delete FrameTypeSP;
     delete ImageExposureNP;
     delete ImageBinNP;
@@ -78,6 +85,10 @@ void CCDChip::setResolutoin(int x, int y)
     ImagePixelSizeN[1].value=y;
 
     IDSetNumber(ImagePixelSizeNP, NULL);
+
+    ImageFrameN[FRAME_W].max = x;
+    ImageFrameN[FRAME_H].max = y;
+    IUUpdateMinMax(ImageFrameNP);
 }
 
 void CCDChip::setFrame(int subx, int suby, int subw, int subh)
@@ -87,10 +98,10 @@ void CCDChip::setFrame(int subx, int suby, int subw, int subh)
     SubW = subw;
     SubH = subh;
 
-    ImageFrameN[0].value = SubX;
-    ImageFrameN[1].value = SubY;
-    ImageFrameN[2].value = SubW;
-    ImageFrameN[3].value = SubH;
+    ImageFrameN[FRAME_X].value = SubX;
+    ImageFrameN[FRAME_Y].value = SubY;
+    ImageFrameN[FRAME_W].value = SubW;
+    ImageFrameN[FRAME_H].value = SubH;
 
     IDSetNumber(ImageFrameNP, NULL);
 }
@@ -100,13 +111,13 @@ void CCDChip::setBin(int hor, int ver)
     BinX = hor;
     BinY = ver;
 
-    ImageBinN[0].value = BinX;
-    ImageBinN[1].value = BinY;
+    ImageBinN[BIN_W].value = BinX;
+    ImageBinN[BIN_H].value = BinY;
 
     IDSetNumber(ImageBinNP, NULL);
 }
 
-void CCDChip::setPixelSize(int x, int y)
+void CCDChip::setPixelSize(float x, float y)
 {
     PixelSizex = x;
     PixelSizey = y;
@@ -130,20 +141,43 @@ void CCDChip::setBPP(int bbp)
 
 void CCDChip::setFrameBufferSize(int nbuf)
 {
+    if (nbuf == RawFrameSize)
+        return;
+
     if (RawFrame != NULL)
         delete RawFrame;
 
+
     RawFrameSize = nbuf;
 
     RawFrame = new char[nbuf];
 }
 
-void CCDChip::setExposure(double duration)
+void CCDChip::setExposureLeft(double duration)
 {
     ImageExposureN[0].value = duration;
+
     IDSetNumber(ImageExposureNP, NULL);
 }
 
+void CCDChip::setExposureDuration(double duration)
+{
+    exposureDuration = duration;
+    gettimeofday(&startExposureTime,NULL);
+}
+
+const char * CCDChip::getExposureStartTime()
+{
+    static char ts[32];
+    struct tm *tp;
+    time_t t = (time_t) startExposureTime.tv_sec;
+
+    //time (&t);
+    tp = gmtime (&t);
+    strftime (ts, sizeof(ts), "%Y-%m-%dT%H:%M:%S", tp);
+    return (ts);
+}
+
 void CCDChip::setInterlaced(bool intr)
 {
     Interlaced = intr;
@@ -161,17 +195,17 @@ INDI::CCD::CCD()
     HasGuideHead=false;
     HasSt4Port=false;
     InExposure=false;
-    TelescopeTP = new ITextVectorProperty;
+    ActiveDeviceTP = new ITextVectorProperty;
 }
 
 INDI::CCD::~CCD()
 {
-    delete TelescopeTP;
+    delete ActiveDeviceTP;
 }
 
 bool INDI::CCD::initProperties()
 {
-    DefaultDriver::initProperties();   //  let the base class flesh in what it wants
+    DefaultDevice::initProperties();   //  let the base class flesh in what it wants
 
     // PRIMARY CCD Init
 
@@ -179,20 +213,23 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&PrimaryCCD.ImageFrameN[1],"Y","Top","%4.0f",0,1040,0,0);
     IUFillNumber(&PrimaryCCD.ImageFrameN[2],"WIDTH","Width","%4.0f",0,1392.0,0,1392.0);
     IUFillNumber(&PrimaryCCD.ImageFrameN[3],"HEIGHT","Height","%4.0f",0,1040,0,1040);
-    IUFillNumberVector(PrimaryCCD.ImageFrameNP,PrimaryCCD.ImageFrameN,4,deviceName(),"CCD_FRAME","Frame",IMAGE_SETTINGS_TAB,IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(PrimaryCCD.ImageFrameNP,PrimaryCCD.ImageFrameN,4,getDeviceName(),"CCD_FRAME","Frame",IMAGE_SETTINGS_TAB,IP_RW,60,IPS_IDLE);
 
     IUFillSwitch(&PrimaryCCD.FrameTypeS[0],"FRAME_LIGHT","Light",ISS_ON);
     IUFillSwitch(&PrimaryCCD.FrameTypeS[1],"FRAME_BIAS","Bias",ISS_OFF);
     IUFillSwitch(&PrimaryCCD.FrameTypeS[2],"FRAME_DARK","Dark",ISS_OFF);
     IUFillSwitch(&PrimaryCCD.FrameTypeS[3],"FRAME_FLAT","Flat",ISS_OFF);
-    IUFillSwitchVector(PrimaryCCD.FrameTypeSP,PrimaryCCD.FrameTypeS,4,deviceName(),"CCD_FRAME_TYPE","FrameType",IMAGE_SETTINGS_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitchVector(PrimaryCCD.FrameTypeSP,PrimaryCCD.FrameTypeS,4,getDeviceName(),"CCD_FRAME_TYPE","FrameType",IMAGE_SETTINGS_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillNumber(&PrimaryCCD.ImageExposureN[0],"CCD_EXPOSURE_VALUE","Duration (s)","%5.2f",0,36000,0,1.0);
-    IUFillNumberVector(PrimaryCCD.ImageExposureNP,PrimaryCCD.ImageExposureN,1,deviceName(),"CCD_EXPOSURE_REQUEST","Expose",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(PrimaryCCD.ImageExposureNP,PrimaryCCD.ImageExposureN,1,getDeviceName(),"CCD_EXPOSURE","Expose",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
+
+    IUFillSwitch(&PrimaryCCD.AbortExposureS[0],"ABORT","Abort",ISS_OFF);
+    IUFillSwitchVector(PrimaryCCD.AbortExposureSP,PrimaryCCD.AbortExposureS,1,getDeviceName(),"CCD_ABORT_EXPOSURE","Expose Abort",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillNumber(&PrimaryCCD.ImageBinN[0],"HOR_BIN","X","%2.0f",1,4,1,1);
     IUFillNumber(&PrimaryCCD.ImageBinN[1],"VER_BIN","Y","%2.0f",1,4,1,1);
-    IUFillNumberVector(PrimaryCCD.ImageBinNP,PrimaryCCD.ImageBinN,2,deviceName(),"CCD_BINNING","Binning",IMAGE_SETTINGS_TAB,IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(PrimaryCCD.ImageBinNP,PrimaryCCD.ImageBinN,2,getDeviceName(),"CCD_BINNING","Binning",IMAGE_SETTINGS_TAB,IP_RW,60,IPS_IDLE);
 
     IUFillNumber(&PrimaryCCD.ImagePixelSizeN[0],"CCD_MAX_X","Resolution x","%4.0f",1,40,0,6.45);
     IUFillNumber(&PrimaryCCD.ImagePixelSizeN[1],"CCD_MAX_Y","Resolution y","%4.0f",1,40,0,6.45);
@@ -200,14 +237,14 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&PrimaryCCD.ImagePixelSizeN[3],"CCD_PIXEL_SIZE_X","Pixel size X","%5.2f",1,40,0,6.45);
     IUFillNumber(&PrimaryCCD.ImagePixelSizeN[4],"CCD_PIXEL_SIZE_Y","Pixel size Y","%5.2f",1,40,0,6.45);
     IUFillNumber(&PrimaryCCD.ImagePixelSizeN[5],"CCD_BITSPERPIXEL","Bits per pixel","%3.0f",1,40,0,6.45);
-    IUFillNumberVector(PrimaryCCD.ImagePixelSizeNP,PrimaryCCD.ImagePixelSizeN,6,deviceName(),"CCD_INFO","Ccd Information",IMAGE_INFO_TAB,IP_RO,60,IPS_IDLE);
+    IUFillNumberVector(PrimaryCCD.ImagePixelSizeNP,PrimaryCCD.ImagePixelSizeN,6,getDeviceName(),"CCD_INFO","CCD Information",IMAGE_INFO_TAB,IP_RO,60,IPS_IDLE);
 
     IUFillSwitch(&PrimaryCCD.CompressS[0],"COMPRESS","Compress",ISS_OFF);
     IUFillSwitch(&PrimaryCCD.CompressS[1],"RAW","Raw",ISS_ON);
-    IUFillSwitchVector(PrimaryCCD.CompressSP,PrimaryCCD.CompressS,2,deviceName(),"COMPRESSION","Image",IMAGE_SETTINGS_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitchVector(PrimaryCCD.CompressSP,PrimaryCCD.CompressS,2,getDeviceName(),"COMPRESSION","Image",IMAGE_SETTINGS_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillBLOB(&PrimaryCCD.FitsB,"CCD1","Image","");
-    IUFillBLOBVector(PrimaryCCD.FitsBP,&PrimaryCCD.FitsB,1,deviceName(),"CCD1","Image Data",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
+    IUFillBLOBVector(PrimaryCCD.FitsBP,&PrimaryCCD.FitsB,1,getDeviceName(),"CCD1","Image Data",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
 
     // GUIDER CCD Init
 
@@ -215,37 +252,46 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&GuideCCD.ImageFrameN[1],"Y","Top","%4.0f",0,1040,0,0);
     IUFillNumber(&GuideCCD.ImageFrameN[2],"WIDTH","Width","%4.0f",0,1392.0,0,1392.0);
     IUFillNumber(&GuideCCD.ImageFrameN[3],"HEIGHT","Height","%4.0f",0,1040,0,1040);
-    IUFillNumberVector(GuideCCD.ImageFrameNP,GuideCCD.ImageFrameN,4,deviceName(),"GUIDE_FRAME","Frame",GUIDE_HEAD_TAB,IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(GuideCCD.ImageFrameNP,GuideCCD.ImageFrameN,4,getDeviceName(),"GUIDE_FRAME","Frame",GUIDE_HEAD_TAB,IP_RW,60,IPS_IDLE);
 
-    IUFillNumber(&GuideCCD.ImagePixelSizeN[0],"Image_MAX_X","Resolution x","%4.0f",1,40,0,6.45);
-    IUFillNumber(&GuideCCD.ImagePixelSizeN[1],"Image_MAX_Y","Resolution y","%4.0f",1,40,0,6.45);
-    IUFillNumber(&GuideCCD.ImagePixelSizeN[2],"Image_PIXEL_SIZE","Pixel size (um)","%5.2f",1,40,0,6.45);
-    IUFillNumber(&GuideCCD.ImagePixelSizeN[3],"Image_PIXEL_SIZE_X","Pixel size X","%5.2f",1,40,0,6.45);
-    IUFillNumber(&GuideCCD.ImagePixelSizeN[4],"Image_PIXEL_SIZE_Y","Pixel size Y","%5.2f",1,40,0,6.45);
-    IUFillNumber(&GuideCCD.ImagePixelSizeN[5],"Image_BITSPERPIXEL","Bits per pixel","%3.0f",1,40,0,6.45);
-    IUFillNumberVector(GuideCCD.ImagePixelSizeNP,GuideCCD.ImagePixelSizeN,6,deviceName(),"GUIDE_INFO",GUIDE_HEAD_TAB,GUIDE_HEAD_TAB,IP_RO,60,IPS_IDLE);
+    IUFillNumber(&GuideCCD.ImagePixelSizeN[0],"CCD_MAX_X","Resolution x","%4.0f",1,40,0,6.45);
+    IUFillNumber(&GuideCCD.ImagePixelSizeN[1],"CCD_MAX_Y","Resolution y","%4.0f",1,40,0,6.45);
+    IUFillNumber(&GuideCCD.ImagePixelSizeN[2],"CCD_PIXEL_SIZE","Pixel size (um)","%5.2f",1,40,0,6.45);
+    IUFillNumber(&GuideCCD.ImagePixelSizeN[3],"CCD_PIXEL_SIZE_X","Pixel size X","%5.2f",1,40,0,6.45);
+    IUFillNumber(&GuideCCD.ImagePixelSizeN[4],"CCD_PIXEL_SIZE_Y","Pixel size Y","%5.2f",1,40,0,6.45);
+    IUFillNumber(&GuideCCD.ImagePixelSizeN[5],"CCD_BITSPERPIXEL","Bits per pixel","%3.0f",1,40,0,6.45);
+    IUFillNumberVector(GuideCCD.ImagePixelSizeNP,GuideCCD.ImagePixelSizeN,6,getDeviceName(),"GUIDE_INFO",GUIDE_HEAD_TAB,GUIDE_HEAD_TAB,IP_RO,60,IPS_IDLE);
 
     IUFillNumber(&GuideCCD.ImageExposureN[0],"GUIDER_EXPOSURE_VALUE","Duration (s)","%5.2f",0,36000,0,1.0);
-    IUFillNumberVector(GuideCCD.ImageExposureNP,GuideCCD.ImageExposureN,1,deviceName(),"GUIDER_EXPOSURE","Image",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(GuideCCD.ImageExposureNP,GuideCCD.ImageExposureN,1,getDeviceName(),"GUIDER_EXPOSURE","Guide",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
+
+    IUFillSwitch(&GuideCCD.AbortExposureS[0],"ABORT","Abort",ISS_OFF);
+    IUFillSwitchVector(GuideCCD.AbortExposureSP,GuideCCD.AbortExposureS,1,getDeviceName(),"GUIDER_ABORT_EXPOSURE","Guide Abort",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillSwitch(&GuideCCD.CompressS[0],"GCOMPRESS","Compress",ISS_OFF);
     IUFillSwitch(&GuideCCD.CompressS[1],"GRAW","Raw",ISS_ON);
-    IUFillSwitchVector(GuideCCD.CompressSP,GuideCCD.CompressS,2,deviceName(),"GCOMPRESSION","Image",GUIDE_HEAD_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitchVector(GuideCCD.CompressSP,GuideCCD.CompressS,2,getDeviceName(),"GCOMPRESSION","Image",GUIDE_HEAD_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillBLOB(&GuideCCD.FitsB,"CCD2","Guider Image","");
-    IUFillBLOBVector(GuideCCD.FitsBP,&GuideCCD.FitsB,1,deviceName(),"CCD2","Image Data",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
+    IUFillBLOBVector(GuideCCD.FitsBP,&GuideCCD.FitsB,1,getDeviceName(),"CCD2","Image Data",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
 
     // CCD Class Init
 
-    IUFillText(&TelescopeT[0],"ACTIVE_TELESCOPE","Telescope","");
-    IUFillTextVector(TelescopeTP,TelescopeT,1,deviceName(),"ACTIVE_DEVICES","Snoop Scope",OPTIONS_TAB,IP_RW,60,IPS_IDLE);
+    IUFillText(&ActiveDeviceT[0],"ACTIVE_TELESCOPE","Telescope","Telescope Simulator");
+    IUFillText(&ActiveDeviceT[1],"ACTIVE_FOCUSER","Focuser","Focuser Simulator");
+    IUFillTextVector(ActiveDeviceTP,ActiveDeviceT,2,getDeviceName(),"ACTIVE_DEVICES","Snoop devices",OPTIONS_TAB,IP_RW,60,IPS_IDLE);
+
+    IUFillNumber(&EqN[0],"RA","Ra (hh:mm:ss)","%010.6m",0,24,0,0);
+    IUFillNumber(&EqN[1],"DEC","Dec (dd:mm:ss)","%010.6m",-90,90,0,0);
+    IUFillNumberVector(&EqNP,EqN,2,ActiveDeviceT[0].text,"EQUATORIAL_COORD","EQ Coord","Main Control",IP_RW,60,IPS_IDLE);
+
+    IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_COORD");
+    IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
+    IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
 
-    IUFillNumber(&EqN[0],"RA_PEC","Ra (hh:mm:ss)","%010.6m",0,24,0,0);
-    IUFillNumber(&EqN[1],"DEC_PEC","Dec (dd:mm:ss)","%010.6m",-90,90,0,0);
-    IUFillNumberVector(&EqNP,EqN,2,"","EQUATORIAL_PEC","EQ PEC","Main Control",IP_RW,60,IPS_IDLE);
 
     // Guider Interface
-    initGuiderProperties(deviceName(), GUIDE_CONTROL_TAB);
+    initGuiderProperties(getDeviceName(), GUIDE_CONTROL_TAB);
 
     return true;
 }
@@ -256,7 +302,7 @@ void INDI::CCD::ISGetProperties (const char *dev)
 
     //IDLog("INDI::CCD IsGetProperties with %s\n",dev);
 
-    DefaultDriver::ISGetProperties(dev);
+    DefaultDevice::ISGetProperties(dev);
 
     return;
 }
@@ -266,14 +312,16 @@ bool INDI::CCD::updateProperties()
     //IDLog("INDI::CCD UpdateProperties isConnected returns %d %d\n",isConnected(),Connected);
     if(isConnected())
     {
-        defineNumber(PrimaryCCD.ImageExposureNP);
+       defineNumber(PrimaryCCD.ImageExposureNP);
+       defineSwitch(PrimaryCCD.AbortExposureSP);
         defineNumber(PrimaryCCD.ImageFrameNP);
         defineNumber(PrimaryCCD.ImageBinNP);
 
         if(HasGuideHead)
         {
-            IDLog("Sending Guider Stuff\n");
+           // IDLog("Sending Guider Stuff\n");
             defineNumber(GuideCCD.ImageExposureNP);
+            defineSwitch(GuideCCD.AbortExposureSP);
             defineNumber(GuideCCD.ImageFrameNP);
         }
 
@@ -291,11 +339,11 @@ bool INDI::CCD::updateProperties()
         }
         if(HasSt4Port)
         {
-            defineNumber(GuideNSP);
-            defineNumber(GuideEWP);
+            defineNumber(&GuideNSP);
+            defineNumber(&GuideEWP);
         }
         defineSwitch(PrimaryCCD.FrameTypeSP);
-        defineText(TelescopeTP);
+        defineText(ActiveDeviceTP);
     }
     else
     {
@@ -303,11 +351,13 @@ bool INDI::CCD::updateProperties()
         deleteProperty(PrimaryCCD.ImageBinNP->name);
         deleteProperty(PrimaryCCD.ImagePixelSizeNP->name);
         deleteProperty(PrimaryCCD.ImageExposureNP->name);
+        deleteProperty(PrimaryCCD.AbortExposureSP->name);
         deleteProperty(PrimaryCCD.FitsBP->name);
         deleteProperty(PrimaryCCD.CompressSP->name);
         if(HasGuideHead)
         {
             deleteProperty(GuideCCD.ImageExposureNP->name);
+            deleteProperty(GuideCCD.AbortExposureSP->name);
             deleteProperty(GuideCCD.ImageFrameNP->name);
             deleteProperty(GuideCCD.ImagePixelSizeNP->name);
             deleteProperty(GuideCCD.FitsBP->name);
@@ -315,17 +365,17 @@ bool INDI::CCD::updateProperties()
         }
         if(HasSt4Port)
         {
-            deleteProperty(GuideNSP->name);
-            deleteProperty(GuideEWP->name);
+            deleteProperty(GuideNSP.name);
+            deleteProperty(GuideEWP.name);
 
         }
         deleteProperty(PrimaryCCD.FrameTypeSP->name);
-        deleteProperty(TelescopeTP->name);
+        deleteProperty(ActiveDeviceTP->name);
     }
     return true;
 }
 
-void INDI::CCD::ISSnoopDevice (XMLEle *root)
+bool INDI::CCD::ISSnoopDevice (XMLEle *root)
  {
      //fprintf(stderr," ################# CCDSim handling snoop ##############\n");
      if(IUSnoopNumber(root,&EqNP)==0)
@@ -345,6 +395,8 @@ void INDI::CCD::ISSnoopDevice (XMLEle *root)
      {
         //fprintf(stderr,"Snoop Failed\n");
      }
+
+     return true;
  }
 
 bool INDI::CCD::ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n)
@@ -352,40 +404,43 @@ bool INDI::CCD::ISNewText (const char *dev, const char *name, char *texts[], cha
     //  Ok, lets see if this is a property wer process
     //IDLog("IndiTelescope got %d new text items name %s\n",n,name);
     //  first check if it's for our device
-    if(strcmp(dev,deviceName())==0)
+    if(strcmp(dev,getDeviceName())==0)
     {
         //  This is for our device
         //  Now lets see if it's something we process here
-        if(strcmp(name,TelescopeTP->name)==0)
+        if(strcmp(name,ActiveDeviceTP->name)==0)
         {
             int rc;
             //IDLog("calling update text\n");
-            TelescopeTP->s=IPS_OK;
-            rc=IUUpdateText(TelescopeTP,texts,names,n);
+            ActiveDeviceTP->s=IPS_OK;
+            rc=IUUpdateText(ActiveDeviceTP,texts,names,n);
             //IDLog("update text returns %d\n",rc);
             //  Update client display
-            IDSetText(TelescopeTP,NULL);
+            IDSetText(ActiveDeviceTP,NULL);
             saveConfig();
-            IUFillNumberVector(&EqNP,EqN,2,TelescopeT[0].text,"EQUATORIAL_PEC","EQ PEC",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
-            IDSnoopDevice(TelescopeT[0].text,"EQUATORIAL_PEC");
+            IUFillNumberVector(&EqNP,EqN,2,ActiveDeviceT[0].text,"EQUATORIAL_PEC","EQ PEC",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
+
+            IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PEC");
+            IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
+            IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
             //  We processed this one, so, tell the world we did it
             return true;
         }
 
     }
 
-    return INDI::DefaultDriver::ISNewText(dev,name,texts,names,n);
+    return INDI::DefaultDevice::ISNewText(dev,name,texts,names,n);
 }
 
 bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n)
 {
     //  first check if it's for our device
     //IDLog("INDI::CCD::ISNewNumber %s\n",name);
-    if(strcmp(dev,deviceName())==0)
+    if(strcmp(dev,getDeviceName())==0)
     {
         //  This is for our device
         //  Now lets see if it's something we process here
-        if(strcmp(name,"CCD_EXPOSURE_REQUEST")==0)
+        if(strcmp(name,"CCD_EXPOSURE")==0)
         {
             float n;
             int rc;
@@ -433,7 +488,7 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
 
             //  And now call the physical hardware layer to start the exposure
             //  change of plans, this is just changing exposure time
-            //  the the start/stop stream buttons do the rest
+            //  the start/stop stream buttons do the rest
             rc=StartGuideExposure(n);
             //rc=1;   //  set it to ok
             switch(rc) {
@@ -457,34 +512,30 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
             PrimaryCCD.ImageBinNP->s=IPS_OK;
             IUUpdateNumber(PrimaryCCD.ImageBinNP,values,names,n);
 
-            // Let child classes know of CCD BIN changes
-            // If child processes and updates bin (true) then no further action is needed
-            // if child class does not do any processing, then we simply update the values.
+
             if (updateCCDBin(PrimaryCCD.ImageBinN[0].value, PrimaryCCD.ImageBinN[1].value) == false)
-                PrimaryCCD.setBin(PrimaryCCD.ImageBinN[0].value, PrimaryCCD.ImageBinN[1].value);
+            {
+                PrimaryCCD.ImageBinNP->s = IPS_ALERT;
+                IDSetNumber (PrimaryCCD.ImageBinNP, NULL);
+            }
 
             return true;
 
-        }
+      }
 
         if(strcmp(name,"CCD_FRAME")==0)
         {
             //  We are being asked to set camera binning
             PrimaryCCD.ImageFrameNP->s=IPS_OK;
             IUUpdateNumber(PrimaryCCD.ImageFrameNP,values,names,n);
-            //  Update client display
-            //IDSetNumber(PrimaryCCD.ImageFrameNP,NULL);
-
-            //IDLog("Frame set to %4.0f,%4.0f %4.0f x %4.0f\n",CcdFrameN[0].value,CcdFrameN[1].value,CcdFrameN[2].value,CcdFrameN[3].value);
-            //SubX=PrimaryCCD.ImageFrameN[0].value;
-            //SubY=PrimaryCCD.ImageFrameN[1].value;
-            //SubW=PrimaryCCD.ImageFrameN[2].value;
-            //SubH=PrimaryCCD.ImageFrameN[3].value;
 
             if (updateCCDFrame(PrimaryCCD.ImageFrameN[0].value, PrimaryCCD.ImageFrameN[1].value, PrimaryCCD.ImageFrameN[2].value,
                                PrimaryCCD.ImageFrameN[3].value) == false)
-                PrimaryCCD.setFrame(PrimaryCCD.ImageFrameN[0].value, PrimaryCCD.ImageFrameN[1].value, PrimaryCCD.ImageFrameN[2].value,
-                                    PrimaryCCD.ImageFrameN[3].value);
+            {
+                PrimaryCCD.ImageFrameNP->s = IPS_ALERT;
+                IDSetNumber(PrimaryCCD.ImageFrameNP, NULL);
+
+            }
             return true;
         }
 
@@ -496,7 +547,8 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
             //  Update client display
             //IDSetNumber(GuiderFrameNP,NULL);
 
-            IDLog("GuiderFrame set to %4.0f,%4.0f %4.0f x %4.0f\n",
+            if (isDebug())
+                IDLog("GuiderFrame set to %4.0f,%4.0f %4.0f x %4.0f\n",
                   GuideCCD.ImageFrameN[0].value,GuideCCD.ImageFrameN[1].value,GuideCCD.ImageFrameN[2].value,GuideCCD.ImageFrameN[3].value);
             //GSubX=GuiderFrameN[0].value;
             //GSubY=GuiderFrameN[1].value;
@@ -508,71 +560,71 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
             return true;
         }
 
-        if(strcmp(name,GuideNSP->name)==0)
+        if (!strcmp(name,GuideNSP.name) || !strcmp(name,GuideEWP.name))
         {
-            //  We are being asked to send a guide pulse north/south on the st4 port
-            GuideNSP->s=IPS_BUSY;
-            IUUpdateNumber(GuideNSP,values,names,n);
-            //  Update client display
-            IDSetNumber(GuideNSP,NULL);
-
-            fprintf(stderr,"GuideNorthSouth set to %7.3f,%7.3f\n", GuideNS[0].value,GuideNS[1].value);
-
-            if(GuideNS[0].value != 0)
-            {
-                GuideNorth(GuideNS[0].value);
-            }
-            if(GuideNS[1].value != 0) {
-                GuideSouth(GuideNS[1].value);
-            }
-            GuideNS[0].value=0;
-            GuideNS[1].value=0;
-            GuideNSP->s=IPS_OK;
-            IDSetNumber(GuideNSP,NULL);
-
-            return true;
-        }
-
-        if(strcmp(name,GuideEWP->name)==0)
-        {
-            //  We are being asked to send a guide pulse north/south on the st4 port
-            GuideEWP->s=IPS_BUSY;
-            IUUpdateNumber(GuideEWP,values,names,n);
-            //  Update client display
-            IDSetNumber(GuideEWP,NULL);
-
-            fprintf(stderr,"GuiderEastWest set to %6.3f,%6.3f\n",
-                  GuideEW[0].value,GuideEW[1].value);
-
-            if(GuideEW[0].value != 0)
-            {
-                GuideEast(GuideEW[0].value);
-            } else
-            {
-                GuideWest(GuideEW[1].value);
-            }
-
-            GuideEW[0].value=0;
-            GuideEW[1].value=0;
-            GuideEWP->s=IPS_OK;
-            IDSetNumber(GuideEWP,NULL);
-
+            processGuiderProperties(name, values, names, n);
             return true;
         }
 
     }
     //  if we didn't process it, continue up the chain, let somebody else
     //  give it a shot
-    return DefaultDriver::ISNewNumber(dev,name,values,names,n);
+    return DefaultDevice::ISNewNumber(dev,name,values,names,n);
 }
 
 bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n)
 {
 
-    if(strcmp(dev,deviceName())==0)
+    if(strcmp(dev,getDeviceName())==0)
     {
 
 
+        if(strcmp(name,PrimaryCCD.AbortExposureSP->name)==0)
+        {
+            IUResetSwitch(PrimaryCCD.AbortExposureSP);
+
+            if (AbortExposure())
+            {
+                PrimaryCCD.AbortExposureSP->s = IPS_OK;
+                PrimaryCCD.ImageExposureNP->s = IPS_IDLE;
+                PrimaryCCD.ImageExposureN[0].value = 0;
+            }
+            else
+            {
+                PrimaryCCD.AbortExposureSP->s = IPS_ALERT;
+                PrimaryCCD.ImageExposureNP->s = IPS_ALERT;
+            }
+
+            IDSetSwitch(PrimaryCCD.AbortExposureSP, NULL);
+            IDSetNumber(PrimaryCCD.ImageExposureNP, NULL);
+
+            return true;
+        }
+
+
+        if(strcmp(name,GuideCCD.AbortExposureSP->name)==0)
+        {
+            IUResetSwitch(GuideCCD.AbortExposureSP);
+
+            if (AbortGuideExposure())
+            {
+                GuideCCD.AbortExposureSP->s = IPS_OK;
+                GuideCCD.ImageExposureNP->s = IPS_IDLE;
+                GuideCCD.ImageExposureN[0].value = 0;
+            }
+            else
+            {
+                GuideCCD.AbortExposureSP->s = IPS_ALERT;
+                GuideCCD.ImageExposureNP->s = IPS_ALERT;
+            }
+
+            IDSetSwitch(GuideCCD.AbortExposureSP, NULL);
+            IDSetNumber(GuideCCD.ImageExposureNP, NULL);
+
+            return true;
+        }
+
+
         if(strcmp(name,PrimaryCCD.CompressSP->name)==0)
         {
 
@@ -611,18 +663,22 @@ bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states,
             IUUpdateSwitch(PrimaryCCD.FrameTypeSP,states,names,n);
             PrimaryCCD.FrameTypeSP->s=IPS_OK;
             if(PrimaryCCD.FrameTypeS[0].s==ISS_ON) PrimaryCCD.setFrameType(CCDChip::LIGHT_FRAME);
-            if(PrimaryCCD.FrameTypeS[1].s==ISS_ON) PrimaryCCD.setFrameType(CCDChip::BIAS_FRAME);
-            if(PrimaryCCD.FrameTypeS[2].s==ISS_ON) PrimaryCCD.setFrameType(CCDChip::DARK_FRAME);
-            if(PrimaryCCD.FrameTypeS[3].s==ISS_ON) PrimaryCCD.setFrameType(CCDChip::FLAT_FRAME);
+            else if(PrimaryCCD.FrameTypeS[1].s==ISS_ON) PrimaryCCD.setFrameType(CCDChip::BIAS_FRAME);
+            else if(PrimaryCCD.FrameTypeS[2].s==ISS_ON) PrimaryCCD.setFrameType(CCDChip::DARK_FRAME);
+            else if(PrimaryCCD.FrameTypeS[3].s==ISS_ON) PrimaryCCD.setFrameType(CCDChip::FLAT_FRAME);
+
+            if (updateCCDFrameType(PrimaryCCD.getFrameType()) == false)
+                PrimaryCCD.FrameTypeSP->s = IPS_ALERT;
 
             IDSetSwitch(PrimaryCCD.FrameTypeSP,NULL);
+
             return true;
         }
     }
 
 
     // let the default driver have a crack at it
-    return DefaultDriver::ISNewSwitch(dev, name, states, names, n);
+    return DefaultDevice::ISNewSwitch(dev, name, states, names, n);
 }
 
 
@@ -646,38 +702,131 @@ bool INDI::CCD::AbortExposure()
 
 bool INDI::CCD::updateCCDFrame(int x, int y, int w, int h)
 {
-    // Nothing to do here. HW layer should take care of it if needed.
-    return false;
+    // Just set value, unless HW layer overrides this and performs its own processing
+    PrimaryCCD.setFrame(x, y, w, h);
+    return true;
 }
 
 bool INDI::CCD::updateCCDBin(int hor, int ver)
 {
-    // Nothing to do here. HW layer should take care of it if needed.
-    return false;
+    // Just set value, unless HW layer overrides this and performs its own processing
+    PrimaryCCD.setBin(hor, ver);
+    return true;
 }
 
-void INDI::CCD::addFITSKeywords(fitsfile *fptr)
+bool INDI::CCD::updateCCDFrameType(CCDChip::CCD_FRAME fType)
 {
-    // Nothing to do here. HW layer should take care of it if needed.
+    INDI_UNUSED(fType);
+    // Child classes can override this
+    return true;
 }
 
-bool INDI::CCD::ExposureComplete()
+void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
+{
+    int status=0;
+    char frame_s[32];
+    char dev_name[32];
+    char exp_start[32];
+    double min_val, max_val;
+    double exposureDuration;
+    double pixSize1,pixSize2;
+    unsigned int xbin, ybin;
+
+    getMinMax(&min_val, &max_val, targetChip);
+
+    xbin = targetChip->getBinX();
+    ybin = targetChip->getBinY();
+
+
+    switch (targetChip->getFrameType())
+    {
+      case CCDChip::LIGHT_FRAME:
+        strcpy(frame_s, "Light");
+    break;
+      case CCDChip::BIAS_FRAME:
+        strcpy(frame_s, "Bias");
+    break;
+      case CCDChip::FLAT_FRAME:
+        strcpy(frame_s, "Flat Field");
+    break;
+      case CCDChip::DARK_FRAME:
+        strcpy(frame_s, "Dark");
+    break;
+    }
+
+    exposureDuration = targetChip->getExposureDuration();
+
+    pixSize1 = targetChip->getPixelSizeX();
+    pixSize2 = targetChip->getPixelSizeY();
+
+    strncpy(dev_name, getDeviceName(), 32);
+    strncpy(exp_start, targetChip->getExposureStartTime(), 32);
+
+    fits_update_key_s(fptr, TDOUBLE, "EXPTIME", &(exposureDuration), "Total Exposure Time (s)", &status);
+
+    if(targetChip->getFrameType() == CCDChip::DARK_FRAME)
+        fits_update_key_s(fptr, TDOUBLE, "DARKTIME", &(exposureDuration), "Total Exposure Time (s)", &status);
+
+    fits_update_key_s(fptr, TDOUBLE, "PIXSIZE1", &(pixSize1), "Pixel Size 1 (microns)", &status);
+    fits_update_key_s(fptr, TDOUBLE, "PIXSIZE2", &(pixSize2), "Pixel Size 2 (microns)", &status);
+    fits_update_key_s(fptr, TUINT, "XBINNING", &(xbin) , "Binning factor in width", &status);
+    fits_update_key_s(fptr, TUINT, "YBINNING", &(ybin), "Binning factor in height", &status);
+    fits_update_key_s(fptr, TSTRING, "FRAME", frame_s, "Frame Type", &status);
+    fits_update_key_s(fptr, TDOUBLE, "DATAMIN", &min_val, "Minimum value", &status);
+    fits_update_key_s(fptr, TDOUBLE, "DATAMAX", &max_val, "Maximum value", &status);
+    fits_update_key_s(fptr, TSTRING, "INSTRUME", dev_name, "CCD Name", &status);
+    fits_update_key_s(fptr, TSTRING, "DATE-OBS", exp_start, "UTC start date of observation", &status);
+
+    //fits_write_date(fptr, &status);
+}
+
+void INDI::CCD::fits_update_key_s(fitsfile* fptr, int type, std::string name, void* p, std::string explanation, int* status)
+{
+        // this function is for removing warnings about deprecated string conversion to char* (from arg 5)
+        fits_update_key(fptr,type,name.c_str(),p, const_cast<char*>(explanation.c_str()), status);
+}
+
+bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
 {
     void *memptr;
     size_t memsize;
+    int img_type=0;
+    int byte_type=0;
     int status=0;
     long naxes[2];
     long naxis=2;
-    int numbytes=0;
+    int nelements=0;
 
     fitsfile *fptr=NULL;
 
-    //IDLog("Enter Exposure Complete %d %d %d %d\n",SubW,SubH,BinX,BinY);
+    naxes[0]=targetChip->getSubW()/targetChip->getBinX();
+    naxes[1]=targetChip->getSubH()/targetChip->getBinY();
 
-    naxes[0]=PrimaryCCD.getSubW()/PrimaryCCD.getBinX();
-    naxes[1]=PrimaryCCD.getSubH()/PrimaryCCD.getBinY();
+    switch (targetChip->getBPP())
+    {
+        case 8:
+            byte_type = TBYTE;
+            img_type  = BYTE_IMG;
+            break;
 
-    numbytes = naxes[0] * naxes[1];
+        case 16:
+            byte_type = TUSHORT;
+            img_type = USHORT_IMG;
+            break;
+
+        case 32:
+            byte_type = TULONG;
+            img_type = ULONG_IMG;
+            break;
+
+         default:
+            IDLog("Unsupported bits per pixel value %d\n", targetChip->getBPP() );
+            return false;
+            break;
+    }
+
+
+    nelements = naxes[0] * naxes[1];
 
     //  Now we have to send fits format data to the client
     memsize=5760;
@@ -696,7 +845,7 @@ bool INDI::CCD::ExposureComplete()
 		return false;
     }
 
-    fits_create_img(fptr, USHORT_IMG , naxis, naxes, &status);
+    fits_create_img(fptr, img_type , naxis, naxes, &status);
 
     if (status)
     {
@@ -705,9 +854,9 @@ bool INDI::CCD::ExposureComplete()
 		return false;
     }
 
-    addFITSKeywords(fptr);
+    addFITSKeywords(fptr, targetChip);
 
-    fits_write_img(fptr,TUSHORT,1,numbytes,PrimaryCCD.getFrameBuffer(),&status);
+    fits_write_img(fptr,byte_type,1,nelements,targetChip->getFrameBuffer(),&status);
 
     if (status)
     {
@@ -718,94 +867,29 @@ bool INDI::CCD::ExposureComplete()
 
     fits_close_file(fptr,&status);
 
+    targetChip->ImageExposureNP->s=IPS_OK;
+    IDSetNumber(targetChip->ImageExposureNP,NULL);
 
-    PrimaryCCD.ImageExposureNP->s=IPS_OK;
-    IDSetNumber(PrimaryCCD.ImageExposureNP,NULL);
 
-    uploadfile(memptr,memsize);
+    targetChip->FitsB.blob=memptr;
+    targetChip->FitsB.bloblen=memsize;
+    targetChip->FitsB.size=memsize;
+    strcpy(targetChip->FitsB.format,".fits");
+    targetChip->FitsBP->s=IPS_OK;
+    //IDLog("Enter Uploadfile with %d total sending via %s, and format %s\n",total,targetChip->FitsB.name, targetChip->FitsB.format);
+    IDSetBLOB(targetChip->FitsBP,NULL);
+
     free(memptr);
     return true;
 }
 
-bool INDI::CCD::GuideExposureComplete()
-{
-        void *memptr;
-        size_t memsize;
-        int status=0;
-        long naxes[2];
-        long naxis=2;
-
-        fitsfile *fptr=NULL;
-        naxes[0]=GuideCCD.getSubW();
-        naxes[1]=GuideCCD.getSubH();
-        //  Now we have to send fits format data to the client
-        memsize=5760;
-        memptr=malloc(memsize);
-        if(!memptr)
-        {
-            IDLog("Error: failed to allocate memory: %lu\n",(unsigned long)memsize);
-        }
-        fits_create_memfile(&fptr,&memptr,&memsize,2880,realloc,&status);
-        if(status)
-        {
-            IDLog("Error: Failed to create FITS image\n");
-            fits_report_error(stderr, status);  /* print out any error messages */
-            return false;
-        }
-        fits_create_img(fptr, BYTE_IMG , naxis, naxes, &status);
-        if (status)
-        {
-            IDLog("Error: Failed to create FITS image\n");
-            fits_report_error(stderr, status);  /* print out any error messages */
-            return false;
-        }
-
-        fits_write_img(fptr,TBYTE,1,naxes[0]*naxes[1],GuideCCD.getFrameBuffer(),&status);
-        if (status)
-        {
-            IDLog("Error: Failed to write FITS image\n");
-            fits_report_error(stderr, status);  /* print out any error messages */
-            return false;
-        }
-        fits_close_file(fptr,&status);
-        IDLog("Built the Guider fits file\n");
-        GuideCCD.ImageExposureNP->s=IPS_OK;
-        IDSetNumber(GuideCCD.ImageExposureNP,NULL);
-
-        IDLog("Sending guider fits file via %s\n",GuideCCD.FitsBP->name);
-        GuideCCD.FitsB.blob=memptr;
-        GuideCCD.FitsB.bloblen=memsize;
-        GuideCCD.FitsB.size=memsize;
-        strcpy(GuideCCD.FitsB.format,".fits");
-        GuideCCD.FitsBP->s=IPS_OK;
-        IDSetBLOB(GuideCCD.FitsBP,NULL);
-        free(memptr);
-
-    return true;
-}
-
-
-int INDI::CCD::uploadfile(void *fitsdata,int total)
-{
-    //  lets try sending a ccd preview
-    //IDLog("Enter Uploadfile with %d total sending via %s\n",total,FitsBP->name);
-    PrimaryCCD.FitsB.blob=fitsdata;
-    PrimaryCCD.FitsB.bloblen=total;
-    PrimaryCCD.FitsB.size=total;
-    strcpy(PrimaryCCD.FitsB.format,".fits");
-    PrimaryCCD.FitsBP->s=IPS_OK;
-    IDSetBLOB(PrimaryCCD.FitsBP,NULL);
-
-    return 0;
-}
-
 void INDI::CCD::SetCCDParams(int x,int y,int bpp,float xf,float yf)
 {
     PrimaryCCD.setResolutoin(x, y);
     PrimaryCCD.setFrame(0, 0, x, y);
     PrimaryCCD.setBin(1,1);
     PrimaryCCD.setPixelSize(xf, yf);
-    PrimaryCCD.setBPP(bpp/8);
+    PrimaryCCD.setBPP(bpp);
 
 }
 
@@ -815,9 +899,8 @@ void INDI::CCD::SetGuidHeadParams(int x,int y,int bpp,float xf,float yf)
 
     GuideCCD.setResolutoin(x, y);
     GuideCCD.setFrame(0, 0, x, y);
-    GuideCCD.setBin(1,1);
     GuideCCD.setPixelSize(xf, yf);
-    GuideCCD.setBPP(bpp/8);
+    GuideCCD.setBPP(bpp);
 
 }
 
@@ -826,6 +909,12 @@ bool INDI::CCD::AbortGuideExposure()
     return false;
 }
 
+bool INDI::CCD::saveConfigItems(FILE *fp)
+{
+    IUSaveConfigText(fp, ActiveDeviceTP);
+
+    return true;
+}
 
 bool INDI::CCD::GuideNorth(float ms)
 {
@@ -844,3 +933,68 @@ bool INDI::CCD::GuideWest(float ms)
     return false;
 }
 
+void INDI::CCD::getMinMax(double *min, double *max, CCDChip *targetChip)
+{
+    int ind=0, i, j;
+    int imageHeight = targetChip->getSubH() / targetChip->getBinY();
+    int imageWidth  = targetChip->getSubW() / targetChip->getBinX();
+    double lmin, lmax;
+
+    switch (targetChip->getBPP())
+    {
+        case 8:
+        {
+            unsigned char *imageBuffer = (unsigned char *) targetChip->getFrameBuffer();
+            lmin = lmax = imageBuffer[0];
+
+
+            for (i= 0; i < imageHeight ; i++)
+                for (j= 0; j < imageWidth; j++)
+                {
+                    ind = (i * imageWidth) + j;
+                    if (imageBuffer[ind] < lmin) lmin = imageBuffer[ind];
+                    else if (imageBuffer[ind] > lmax) lmax = imageBuffer[ind];
+                }
+
+        }
+        break;
+
+        case 16:
+        {
+            unsigned short *imageBuffer = (unsigned short* ) targetChip->getFrameBuffer();
+            lmin = lmax = imageBuffer[0];
+
+            for (i= 0; i < imageHeight ; i++)
+                for (j= 0; j < imageWidth; j++)
+                {
+                    ind = (i * imageWidth) + j;
+                    if (imageBuffer[ind] < lmin) lmin = imageBuffer[ind];
+                     else if (imageBuffer[ind] > lmax) lmax = imageBuffer[ind];
+                }
+
+        }
+        break;
+
+        case 32:
+        {
+            unsigned int *imageBuffer = (unsigned int* ) targetChip->getFrameBuffer();
+            lmin = lmax = imageBuffer[0];
+
+            for (i= 0; i < imageHeight ; i++)
+                for (j= 0; j < imageWidth; j++)
+                {
+                    ind = (i * imageWidth) + j;
+                    if (imageBuffer[ind] < lmin) lmin = imageBuffer[ind];
+                    else if (imageBuffer[ind] > lmax) lmax = imageBuffer[ind];
+
+                }
+
+        }
+        break;
+
+    }
+        *min = lmin;
+        *max = lmax;
+}
+
+
