@@ -19,7 +19,7 @@
 #ifndef INDIFOCUSSER_H
 #define INDIFOCUSSER_H
 
-#include "defaultdriver.h"
+#include "defaultdevice.h"
 
 /**
  * \class INDI::Focuser
@@ -29,7 +29,7 @@
 
 \author Gerry Rozema
 */
-class INDI::Focuser : public INDI::DefaultDriver
+class INDI::Focuser : public INDI::DefaultDevice
 {
     public:
         Focuser();
@@ -43,7 +43,7 @@ class INDI::Focuser : public INDI::DefaultDriver
         virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
         virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
         virtual bool ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n);
-        virtual void ISSnoopDevice (XMLEle *root);
+        virtual bool ISSnoopDevice (XMLEle *root);
 
     protected:
 
@@ -55,12 +55,31 @@ class INDI::Focuser : public INDI::DefaultDriver
         */
         virtual bool Move(FocusDirection dir, int speed, int duration);
 
-        INumberVectorProperty *FocusSpeedNP;
+        /** \brief Move the focuser to an absolute position.
+            \param ticks The new position of the focuser.
+            \return Return 0 if motion is completed and focuser reached requested position. Return 1 if focuser started motion to requested position and is in progress.
+                    Return -1 if there is an error.
+        */
+        virtual int MoveAbs(int ticks);
+
+        /** \brief Move the focuser to an relative position.
+            \param dir Direction of focuser, either FOCUS_INWARD or FOCUS_OUTWARD.
+            \param ticks The relative ticks to move.
+            \return Return 0 if motion is completed and focuser reached requested position. Return 1 if focuser started motion to requested position and is in progress.
+                    Return -1 if there is an error.
+        */
+        virtual int MoveRel(FocusDirection dir, unsigned int ticks);
+
+        INumberVectorProperty FocusSpeedNP;
         INumber FocusSpeedN[1];
-        ISwitchVectorProperty *FocusMotionSP; //  A Switch in the client interface to park the scope
+        ISwitchVectorProperty FocusMotionSP; //  A Switch in the client interface to park the scope
         ISwitch FocusMotionS[2];
-        INumberVectorProperty *FocusTimerNP;
+        INumberVectorProperty FocusTimerNP;
         INumber FocusTimerN[1];
+        INumberVectorProperty FocusAbsPosNP;
+        INumber FocusAbsPosN[1];
+        INumberVectorProperty FocusRelPosNP;
+        INumber FocusRelPosN[1];
 
 };
 
