@@ -19,7 +19,7 @@
 #ifndef INDI_TELESCOPE_H
 #define INDI_TELESCOPE_H
 
-#include "defaultdriver.h"
+#include "defaultdevice.h"
 
 /**
  * \class INDI::Telescope
@@ -41,7 +41,7 @@
 \author Gerry Rozema, Jasem Mutlaq
 \see TelescopeSimulator and SynScan drivers for examples of implementations of INDI::Telescope.
 */
-class INDI::Telescope : public INDI::DefaultDriver
+class INDI::Telescope : public INDI::DefaultDevice
 {
     private:
 
@@ -99,17 +99,23 @@ class INDI::Telescope : public INDI::DefaultDriver
          </ol>
           \return True if reading scope status is OK, false if an error is encounterd.
           \note This function is not implemented in INDI::Telescope, it must be implemented in the child class */
-        virtual bool ReadScopeStatus();
+        virtual bool ReadScopeStatus()=0;
 
         /** \brief Move the scope to the supplied RA and DEC coordinates
             \return True if successful, false otherewise
             \note This function is not implemented in INDI::Telescope, it must be implemented in the child class
         */
-        virtual bool Goto(double ra,double dec);
+        virtual bool Goto(double ra,double dec)=0;
+
+        /** \brief Does the mount support sync?
+         *  \return True if sync is supported, false otherwise.
+         *\note This function is not implemented in INDI::Telescope, it must be implemented in the child class
+        */
+        virtual bool canSync();
 
         /** \brief Set the telescope current RA and DEC coordinates to the supplied RA and DEC coordinates
             \return True if successful, false otherewise
-            \note This function is not implemented in INDI::Telescope, it must be implemented in the child class
+            *\note This function implemented INDI::Telescope always returns false. Override the function to return true.
         */
         virtual bool Sync(double ra,double dec);
 
@@ -125,12 +131,23 @@ class INDI::Telescope : public INDI::DefaultDriver
         */
         virtual bool MoveWE(TelescopeMotionWE dir);
 
-        /** \brief Part the telescope to its home position.
+        /** \brief Does the mount support park?
+         *  \return True if park is supported, false otherwise.
+         *\note This function defaults to return false unless subclassed by the child class.
+        */
+        virtual bool canPark();
+
+        /** \brief Park the telescope to its home position.
             \return True if successful, false otherewise
-            \note This function is not implemented in INDI::Telescope, it must be implemented in the child class
+            *\note This function defaults to return false unless subclassed by the child class.
         */
         virtual bool Park();
 
+        /** \brief Abort telescope motion
+            \return True if successful, false otherewise
+            \note This function is not implemented in INDI::Telescope, it must be implemented in the child class
+        */
+        virtual bool Abort()=0;
 
         //  Since every mount I know of actually uses a serial port for control
         //  We put the serial helper into the base telescope class
@@ -144,34 +161,35 @@ class INDI::Telescope : public INDI::DefaultDriver
         TelescopeStatus TrackState;
 
         //  All telescopes should produce equatorial co-ordinates
-        INumberVectorProperty *EqNV;
+        INumberVectorProperty EqNV;
         INumber EqN[2];
 
-        //  And we need a vector to store requests, ie, where are we asked to go
-        INumberVectorProperty *EqReqNV;
-        INumber EqReqN[2];
+        ISwitchVectorProperty AbortSV; // Abort motion
+        ISwitch AbortS[1];
 
-        ISwitchVectorProperty *CoordSV; //  A switch vector that stores how we should readct
+        ISwitchVectorProperty CoordSV; //  A switch vector that stores how we should readct
         ISwitch CoordS[3];              //  On a coord_set message, sync, or slew
 
-        ISwitchVectorProperty *ConfigSV; //  A switch vector that stores how we should readct
+        ISwitchVectorProperty ConfigSV; //  A switch vector that stores how we should readct
         ISwitch ConfigS[3];              //  On a coord_set message, sync, or slew
 
-        INumberVectorProperty *LocationNV;   //  A number vector that stores lattitude and longitude
+        INumberVectorProperty LocationNV;   //  A number vector that stores lattitude and longitude
         INumber LocationN[2];
 
-        ISwitchVectorProperty *ParkSV; //  A Switch in the client interface to park the scope
+        ISwitchVectorProperty ParkSV; //  A Switch in the client interface to park the scope
         ISwitch ParkS[1];
 
-        ITextVectorProperty *PortTV; //  A text vector that stores out physical port name
+        ITextVectorProperty PortTP; //  A text vector that stores out physical port name
         IText PortT[1];
 
         ISwitch MovementNSS[2];     // A switch for North/South motion
-        ISwitchVectorProperty *MovementNSSP;
+        ISwitchVectorProperty MovementNSSP;
 
         ISwitch MovementWES[2];     // A switch for West/East motion
-        ISwitchVectorProperty *MovementWESP;
+        ISwitchVectorProperty MovementWESP;
 
+        INumber ScopeParametersN[4];
+        INumberVectorProperty ScopeParametersNP;
 
 };
 
