@@ -683,6 +683,7 @@ int tty_connect(const char *device, int bit_rate, int word_size, int parity, int
  if ( (t_fd = open(device, O_RDWR | O_NOCTTY )) == -1)
  {
      *fd = -1;
+
     return TTY_PORT_FAILURE;
  }
 
@@ -916,7 +917,11 @@ void tty_error_msg(int err_code, char *err_msg, int err_msg_len)
 		break;
 
 	case TTY_PORT_FAILURE:
-		snprintf(error_string, 512, "Port failure Error: %s", strerror(errno));
+      if (errno == EACCES)
+        snprintf(error_string, 512, "Port failure Error: %s. Try adding your user to the dialout group and restart (sudo adduser $username dialout)", strerror(errno));
+      else
+        snprintf(error_string, 512, "Port failure Error: %s. Check if device is connected to this port.", strerror(errno));
+
 		strncpy(err_msg, error_string, err_msg_len);
 		break;
 
@@ -1150,6 +1155,17 @@ IUFindOnSwitch(const ISwitchVectorProperty *svp)
         return (NULL);
 }
 
+/* Find index of the ON member of an ISwitchVectorProperty */
+int IUFindOnSwitchIndex(const ISwitchVectorProperty *svp)
+{
+        int i;
+
+        for (i = 0; i < svp->nsp; i++)
+            if (svp->sp[i].s == ISS_ON)
+                return i;
+        return -1;
+}
+
 /* Set all switches to off */
 void
 IUResetSwitch(ISwitchVectorProperty *svp)
